Class: Aws::DatabaseMigrationService::Types::CollectorHealthCheck
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::CollectorHealthCheck
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Describes the last Fleet Advisor collector health check.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#collector_status ⇒ String
The status of the Fleet Advisor collector.
-
#local_collector_s3_access ⇒ Boolean
Whether the local collector can access its Amazon S3 bucket.
-
#web_collector_granted_role_based_access ⇒ Boolean
Whether the role that you provided when creating the Fleet Advisor collector has sufficient permissions to access the Fleet Advisor web collector.
-
#web_collector_s3_access ⇒ Boolean
Whether the web collector can access its Amazon S3 bucket.
Instance Attribute Details
#collector_status ⇒ String
The status of the Fleet Advisor collector.
399 400 401 402 403 404 405 406 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 399 class CollectorHealthCheck < Struct.new( :collector_status, :local_collector_s3_access, :web_collector_s3_access, :web_collector_granted_role_based_access) SENSITIVE = [] include Aws::Structure end |
#local_collector_s3_access ⇒ Boolean
Whether the local collector can access its Amazon S3 bucket.
399 400 401 402 403 404 405 406 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 399 class CollectorHealthCheck < Struct.new( :collector_status, :local_collector_s3_access, :web_collector_s3_access, :web_collector_granted_role_based_access) SENSITIVE = [] include Aws::Structure end |
#web_collector_granted_role_based_access ⇒ Boolean
Whether the role that you provided when creating the Fleet Advisor collector has sufficient permissions to access the Fleet Advisor web collector.
399 400 401 402 403 404 405 406 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 399 class CollectorHealthCheck < Struct.new( :collector_status, :local_collector_s3_access, :web_collector_s3_access, :web_collector_granted_role_based_access) SENSITIVE = [] include Aws::Structure end |
#web_collector_s3_access ⇒ Boolean
Whether the web collector can access its Amazon S3 bucket.
399 400 401 402 403 404 405 406 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 399 class CollectorHealthCheck < Struct.new( :collector_status, :local_collector_s3_access, :web_collector_s3_access, :web_collector_granted_role_based_access) SENSITIVE = [] include Aws::Structure end |