Class: Aws::DatabaseMigrationService::Types::CollectorResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Describes a Fleet Advisor collector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#collector_health_checkTypes::CollectorHealthCheck

Describes the last Fleet Advisor collector health check.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#collector_nameString

The name of the Fleet Advisor collector .



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#collector_referenced_idString

The reference ID of the Fleet Advisor collector.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#collector_versionString

The version of your Fleet Advisor collector, in semantic versioning format, for example 1.0.2



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateString

The timestamp when you created the collector, in the following format: 2022-01-24T19:04:02.596113Z



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A summary description of the Fleet Advisor collector.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#inventory_dataTypes::InventoryData

Describes a Fleet Advisor collector inventory.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#last_data_receivedString

The timestamp of the last time the collector received data, in the following format: 2022-01-24T19:04:02.596113Z



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#modified_dateString

The timestamp when DMS last modified the collector, in the following format: 2022-01-24T19:04:02.596113Z



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#registered_dateString

The timestamp when DMS registered the collector, in the following format: 2022-01-24T19:04:02.596113Z



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_nameString

The Amazon S3 bucket that the Fleet Advisor collector uses to store inventory metadata.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#service_access_role_arnString

The IAM role that grants permissions to access the specified Amazon S3 bucket.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end

#version_statusString

Whether the collector version is up to date.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 476

class CollectorResponse < Struct.new(
  :collector_referenced_id,
  :collector_name,
  :collector_version,
  :version_status,
  :description,
  :s3_bucket_name,
  :service_access_role_arn,
  :collector_health_check,
  :last_data_received,
  :registered_date,
  :created_date,
  :modified_date,
  :inventory_data)
  SENSITIVE = []
  include Aws::Structure
end