Class: Aws::DatabaseMigrationService::Types::CreateDataMigrationMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:selection_rules]

Instance Attribute Summary collapse

Instance Attribute Details

#data_migration_nameString

A user-friendly name for the data migration. Data migration names have the following constraints:

  • Must begin with a letter, and can only contain ASCII letters, digits, and hyphens.

  • Can’t end with a hyphen or contain two consecutive hyphens.

  • Length must be from 1 to 255 characters.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 647

class CreateDataMigrationMessage < Struct.new(
  :data_migration_name,
  :migration_project_identifier,
  :data_migration_type,
  :service_access_role_arn,
  :enable_cloudwatch_logs,
  :source_data_settings,
  :target_data_settings,
  :number_of_jobs,
  :tags,
  :selection_rules)
  SENSITIVE = [:selection_rules]
  include Aws::Structure
end

#data_migration_typeString

Specifies if the data migration is full-load only, change data capture (CDC) only, or full-load and CDC.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 647

class CreateDataMigrationMessage < Struct.new(
  :data_migration_name,
  :migration_project_identifier,
  :data_migration_type,
  :service_access_role_arn,
  :enable_cloudwatch_logs,
  :source_data_settings,
  :target_data_settings,
  :number_of_jobs,
  :tags,
  :selection_rules)
  SENSITIVE = [:selection_rules]
  include Aws::Structure
end

#enable_cloudwatch_logsBoolean

Specifies whether to enable CloudWatch logs for the data migration.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 647

class CreateDataMigrationMessage < Struct.new(
  :data_migration_name,
  :migration_project_identifier,
  :data_migration_type,
  :service_access_role_arn,
  :enable_cloudwatch_logs,
  :source_data_settings,
  :target_data_settings,
  :number_of_jobs,
  :tags,
  :selection_rules)
  SENSITIVE = [:selection_rules]
  include Aws::Structure
end

#migration_project_identifierString

An identifier for the migration project.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 647

class CreateDataMigrationMessage < Struct.new(
  :data_migration_name,
  :migration_project_identifier,
  :data_migration_type,
  :service_access_role_arn,
  :enable_cloudwatch_logs,
  :source_data_settings,
  :target_data_settings,
  :number_of_jobs,
  :tags,
  :selection_rules)
  SENSITIVE = [:selection_rules]
  include Aws::Structure
end

#number_of_jobsInteger

The number of parallel jobs that trigger parallel threads to unload the tables from the source, and then load them to the target.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 647

class CreateDataMigrationMessage < Struct.new(
  :data_migration_name,
  :migration_project_identifier,
  :data_migration_type,
  :service_access_role_arn,
  :enable_cloudwatch_logs,
  :source_data_settings,
  :target_data_settings,
  :number_of_jobs,
  :tags,
  :selection_rules)
  SENSITIVE = [:selection_rules]
  include Aws::Structure
end

#selection_rulesString

An optional JSON string specifying what tables, views, and schemas to include or exclude from the migration.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 647

class CreateDataMigrationMessage < Struct.new(
  :data_migration_name,
  :migration_project_identifier,
  :data_migration_type,
  :service_access_role_arn,
  :enable_cloudwatch_logs,
  :source_data_settings,
  :target_data_settings,
  :number_of_jobs,
  :tags,
  :selection_rules)
  SENSITIVE = [:selection_rules]
  include Aws::Structure
end

#service_access_role_arnString

The Amazon Resource Name (ARN) for the service access role that you want to use to create the data migration.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 647

class CreateDataMigrationMessage < Struct.new(
  :data_migration_name,
  :migration_project_identifier,
  :data_migration_type,
  :service_access_role_arn,
  :enable_cloudwatch_logs,
  :source_data_settings,
  :target_data_settings,
  :number_of_jobs,
  :tags,
  :selection_rules)
  SENSITIVE = [:selection_rules]
  include Aws::Structure
end

#source_data_settingsArray<Types::SourceDataSetting>

Specifies information about the source data provider.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 647

class CreateDataMigrationMessage < Struct.new(
  :data_migration_name,
  :migration_project_identifier,
  :data_migration_type,
  :service_access_role_arn,
  :enable_cloudwatch_logs,
  :source_data_settings,
  :target_data_settings,
  :number_of_jobs,
  :tags,
  :selection_rules)
  SENSITIVE = [:selection_rules]
  include Aws::Structure
end

#tagsArray<Types::Tag>

One or more tags to be assigned to the data migration.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 647

class CreateDataMigrationMessage < Struct.new(
  :data_migration_name,
  :migration_project_identifier,
  :data_migration_type,
  :service_access_role_arn,
  :enable_cloudwatch_logs,
  :source_data_settings,
  :target_data_settings,
  :number_of_jobs,
  :tags,
  :selection_rules)
  SENSITIVE = [:selection_rules]
  include Aws::Structure
end

#target_data_settingsArray<Types::TargetDataSetting>

Specifies information about the target data provider.



647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 647

class CreateDataMigrationMessage < Struct.new(
  :data_migration_name,
  :migration_project_identifier,
  :data_migration_type,
  :service_access_role_arn,
  :enable_cloudwatch_logs,
  :source_data_settings,
  :target_data_settings,
  :number_of_jobs,
  :tags,
  :selection_rules)
  SENSITIVE = [:selection_rules]
  include Aws::Structure
end