Class: Aws::DatabaseMigrationService::Types::CreateFleetAdvisorCollectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::CreateFleetAdvisorCollectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#collector_name ⇒ String
The name of your Fleet Advisor collector (for example,
sample-collector). -
#description ⇒ String
A summary description of your Fleet Advisor collector.
-
#s3_bucket_name ⇒ String
The Amazon S3 bucket that the Fleet Advisor collector uses to store inventory metadata.
-
#service_access_role_arn ⇒ String
The IAM role that grants permissions to access the specified Amazon S3 bucket.
Instance Attribute Details
#collector_name ⇒ String
The name of your Fleet Advisor collector (for example,
sample-collector).
1260 1261 1262 1263 1264 1265 1266 1267 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1260 class CreateFleetAdvisorCollectorRequest < Struct.new( :collector_name, :description, :service_access_role_arn, :s3_bucket_name) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A summary description of your Fleet Advisor collector.
1260 1261 1262 1263 1264 1265 1266 1267 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1260 class CreateFleetAdvisorCollectorRequest < Struct.new( :collector_name, :description, :service_access_role_arn, :s3_bucket_name) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_name ⇒ String
The Amazon S3 bucket that the Fleet Advisor collector uses to store inventory metadata.
1260 1261 1262 1263 1264 1265 1266 1267 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1260 class CreateFleetAdvisorCollectorRequest < Struct.new( :collector_name, :description, :service_access_role_arn, :s3_bucket_name) SENSITIVE = [] include Aws::Structure end |
#service_access_role_arn ⇒ String
The IAM role that grants permissions to access the specified Amazon S3 bucket.
1260 1261 1262 1263 1264 1265 1266 1267 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1260 class CreateFleetAdvisorCollectorRequest < Struct.new( :collector_name, :description, :service_access_role_arn, :s3_bucket_name) SENSITIVE = [] include Aws::Structure end |