Class: Aws::DatabaseMigrationService::Types::CreateMigrationProjectMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A user-friendly description of the migration project.

Returns:

  • (String)


1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1439

class CreateMigrationProjectMessage < Struct.new(
  :migration_project_name,
  :source_data_provider_descriptors,
  :target_data_provider_descriptors,
  :instance_profile_identifier,
  :transformation_rules,
  :description,
  :tags,
  :schema_conversion_application_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#instance_profile_identifierString

The identifier of the associated instance profile. Identifiers must begin with a letter and must contain only ASCII letters, digits, and hyphens. They can't end with a hyphen, or contain two consecutive hyphens.

Returns:

  • (String)


1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1439

class CreateMigrationProjectMessage < Struct.new(
  :migration_project_name,
  :source_data_provider_descriptors,
  :target_data_provider_descriptors,
  :instance_profile_identifier,
  :transformation_rules,
  :description,
  :tags,
  :schema_conversion_application_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#migration_project_nameString

A user-friendly name for the migration project.

Returns:

  • (String)


1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1439

class CreateMigrationProjectMessage < Struct.new(
  :migration_project_name,
  :source_data_provider_descriptors,
  :target_data_provider_descriptors,
  :instance_profile_identifier,
  :transformation_rules,
  :description,
  :tags,
  :schema_conversion_application_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#schema_conversion_application_attributesTypes::SCApplicationAttributes

The schema conversion application attributes, including the Amazon S3 bucket name and Amazon S3 role ARN.



1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1439

class CreateMigrationProjectMessage < Struct.new(
  :migration_project_name,
  :source_data_provider_descriptors,
  :target_data_provider_descriptors,
  :instance_profile_identifier,
  :transformation_rules,
  :description,
  :tags,
  :schema_conversion_application_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#source_data_provider_descriptorsArray<Types::DataProviderDescriptorDefinition>

Information about the source data provider, including the name, ARN, and Secrets Manager parameters.



1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1439

class CreateMigrationProjectMessage < Struct.new(
  :migration_project_name,
  :source_data_provider_descriptors,
  :target_data_provider_descriptors,
  :instance_profile_identifier,
  :transformation_rules,
  :description,
  :tags,
  :schema_conversion_application_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

One or more tags to be assigned to the migration project.

Returns:



1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1439

class CreateMigrationProjectMessage < Struct.new(
  :migration_project_name,
  :source_data_provider_descriptors,
  :target_data_provider_descriptors,
  :instance_profile_identifier,
  :transformation_rules,
  :description,
  :tags,
  :schema_conversion_application_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#target_data_provider_descriptorsArray<Types::DataProviderDescriptorDefinition>

Information about the target data provider, including the name, ARN, and Amazon Web Services Secrets Manager parameters.



1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1439

class CreateMigrationProjectMessage < Struct.new(
  :migration_project_name,
  :source_data_provider_descriptors,
  :target_data_provider_descriptors,
  :instance_profile_identifier,
  :transformation_rules,
  :description,
  :tags,
  :schema_conversion_application_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#transformation_rulesString

A JSON string that specifies the transformation rules for the migration project. Transformation rules let you customize how DMS Schema Conversion converts your source database objects, including renaming, adding prefixes or suffixes, and changing data types. For the transformation rule format and examples, see Transformation rules in DMS Schema Conversion.

Homogeneous data migrations do not support transformation rules.

Returns:

  • (String)


1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 1439

class CreateMigrationProjectMessage < Struct.new(
  :migration_project_name,
  :source_data_provider_descriptors,
  :target_data_provider_descriptors,
  :instance_profile_identifier,
  :transformation_rules,
  :description,
  :tags,
  :schema_conversion_application_attributes)
  SENSITIVE = []
  include Aws::Structure
end