Class: Aws::DatabaseMigrationService::Types::DataProvider

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Provides information that defines a data provider.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_provider_arnString

The Amazon Resource Name (ARN) string that uniquely identifies the data provider.

Returns:

  • (String)


2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205

class DataProvider < Struct.new(
  :data_provider_name,
  :data_provider_arn,
  :data_provider_creation_time,
  :description,
  :engine,
  :virtual,
  :settings)
  SENSITIVE = []
  include Aws::Structure
end

#data_provider_creation_timeTime

The time the data provider was created.

Returns:

  • (Time)


2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205

class DataProvider < Struct.new(
  :data_provider_name,
  :data_provider_arn,
  :data_provider_creation_time,
  :description,
  :engine,
  :virtual,
  :settings)
  SENSITIVE = []
  include Aws::Structure
end

#data_provider_nameString

The name of the data provider.

Returns:

  • (String)


2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205

class DataProvider < Struct.new(
  :data_provider_name,
  :data_provider_arn,
  :data_provider_creation_time,
  :description,
  :engine,
  :virtual,
  :settings)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the data provider. Descriptions can have up to 31 characters. A description can contain only ASCII letters, digits, and hyphens ('-'). Also, it can't end with a hyphen or contain two consecutive hyphens, and can only begin with a letter.

Returns:

  • (String)


2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205

class DataProvider < Struct.new(
  :data_provider_name,
  :data_provider_arn,
  :data_provider_creation_time,
  :description,
  :engine,
  :virtual,
  :settings)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The type of database engine for the data provider.

Valid values: aurora, aurora-postgresql, db2, db2-zos, docdb, mariadb, mongodb, mysql, oracle, postgres, redshift, sqlserver, and sybase. A value of aurora represents Amazon Aurora MySQL-Compatible Edition.

Returns:

  • (String)


2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205

class DataProvider < Struct.new(
  :data_provider_name,
  :data_provider_arn,
  :data_provider_creation_time,
  :description,
  :engine,
  :virtual,
  :settings)
  SENSITIVE = []
  include Aws::Structure
end

#settingsTypes::DataProviderSettings

The settings in JSON format for a data provider.



2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205

class DataProvider < Struct.new(
  :data_provider_name,
  :data_provider_arn,
  :data_provider_creation_time,
  :description,
  :engine,
  :virtual,
  :settings)
  SENSITIVE = []
  include Aws::Structure
end

#virtualBoolean

Indicates whether the data provider is virtual.

Returns:

  • (Boolean)


2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205

class DataProvider < Struct.new(
  :data_provider_name,
  :data_provider_arn,
  :data_provider_creation_time,
  :description,
  :engine,
  :virtual,
  :settings)
  SENSITIVE = []
  include Aws::Structure
end