Class: Aws::DatabaseMigrationService::Types::DescribeApplicableIndividualAssessmentsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeApplicableIndividualAssessmentsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
Maximum number of records to include in the response.
-
#migration_type ⇒ String
Name of the migration type that each provided individual assessment must support.
-
#replication_config_arn ⇒ String
Amazon Resource Name (ARN) of a serverless replication on which you want to base the default list of individual assessments.
-
#replication_instance_arn ⇒ String
ARN of a replication instance on which you want to base the default list of individual assessments.
-
#replication_task_arn ⇒ String
Amazon Resource Name (ARN) of a migration task on which you want to base the default list of individual assessments.
-
#source_engine_name ⇒ String
Name of a database engine that the specified replication instance supports as a source.
-
#target_engine_name ⇒ String
Name of a database engine that the specified replication instance supports as a target.
Instance Attribute Details
#marker ⇒ String
Optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond
the marker, up to the value specified by MaxRecords.
2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2931 class DescribeApplicableIndividualAssessmentsMessage < Struct.new( :replication_task_arn, :replication_instance_arn, :replication_config_arn, :source_engine_name, :target_engine_name, :migration_type, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
Maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so that the
remaining results can be retrieved.
2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2931 class DescribeApplicableIndividualAssessmentsMessage < Struct.new( :replication_task_arn, :replication_instance_arn, :replication_config_arn, :source_engine_name, :target_engine_name, :migration_type, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#migration_type ⇒ String
Name of the migration type that each provided individual assessment must support.
2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2931 class DescribeApplicableIndividualAssessmentsMessage < Struct.new( :replication_task_arn, :replication_instance_arn, :replication_config_arn, :source_engine_name, :target_engine_name, :migration_type, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#replication_config_arn ⇒ String
Amazon Resource Name (ARN) of a serverless replication on which you want to base the default list of individual assessments.
2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2931 class DescribeApplicableIndividualAssessmentsMessage < Struct.new( :replication_task_arn, :replication_instance_arn, :replication_config_arn, :source_engine_name, :target_engine_name, :migration_type, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#replication_instance_arn ⇒ String
ARN of a replication instance on which you want to base the default list of individual assessments.
2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2931 class DescribeApplicableIndividualAssessmentsMessage < Struct.new( :replication_task_arn, :replication_instance_arn, :replication_config_arn, :source_engine_name, :target_engine_name, :migration_type, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#replication_task_arn ⇒ String
Amazon Resource Name (ARN) of a migration task on which you want to base the default list of individual assessments.
2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2931 class DescribeApplicableIndividualAssessmentsMessage < Struct.new( :replication_task_arn, :replication_instance_arn, :replication_config_arn, :source_engine_name, :target_engine_name, :migration_type, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source_engine_name ⇒ String
Name of a database engine that the specified replication instance supports as a source.
2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2931 class DescribeApplicableIndividualAssessmentsMessage < Struct.new( :replication_task_arn, :replication_instance_arn, :replication_config_arn, :source_engine_name, :target_engine_name, :migration_type, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#target_engine_name ⇒ String
Name of a database engine that the specified replication instance supports as a target.
2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2931 class DescribeApplicableIndividualAssessmentsMessage < Struct.new( :replication_task_arn, :replication_instance_arn, :replication_config_arn, :source_engine_name, :target_engine_name, :migration_type, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |