Class: Aws::DatabaseMigrationService::Types::DescribeConversionConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#conversion_configurationString

A JSON string that contains the schema conversion settings for the migration project. For the format and available settings, see Specifying schema conversion settings for migration projects.

Returns:

  • (String)


3104
3105
3106
3107
3108
3109
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3104

class DescribeConversionConfigurationResponse < Struct.new(
  :migration_project_identifier,
  :conversion_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#migration_project_identifierString

The name or Amazon Resource Name (ARN) for the schema conversion project.

Returns:

  • (String)


3104
3105
3106
3107
3108
3109
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3104

class DescribeConversionConfigurationResponse < Struct.new(
  :migration_project_identifier,
  :conversion_configuration)
  SENSITIVE = []
  include Aws::Structure
end