Class: Aws::DatabaseMigrationService::Types::DescribeDataMigrationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_migrationsArray<Types::DataMigration>

Returns information about the data migrations used in the project.

Returns:



3166
3167
3168
3169
3170
3171
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3166

class DescribeDataMigrationsResponse < Struct.new(
  :data_migrations,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


3166
3167
3168
3169
3170
3171
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3166

class DescribeDataMigrationsResponse < Struct.new(
  :data_migrations,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end