Class: Aws::DatabaseMigrationService::Types::DescribeDataProvidersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_providersArray<Types::DataProvider>

A description of data providers.

Returns:



3230
3231
3232
3233
3234
3235
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3230

class DescribeDataProvidersResponse < Struct.new(
  :marker,
  :data_providers)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Specifies the unique pagination token that makes it possible to display the next page of results. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

If Marker is returned by a previous response, there are more results available. The value of Marker is a unique pagination token for each page. To retrieve the next page, make the call again using the returned token and keeping all other arguments unchanged.

Returns:

  • (String)


3230
3231
3232
3233
3234
3235
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3230

class DescribeDataProvidersResponse < Struct.new(
  :marker,
  :data_providers)
  SENSITIVE = []
  include Aws::Structure
end