Class: Aws::DatabaseMigrationService::Types::DescribeEndpointSettingsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#endpoint_settingsArray<Types::EndpointSetting>

Descriptions of the endpoint settings available for your source or target database engine.

Returns:



3277
3278
3279
3280
3281
3282
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3277

class DescribeEndpointSettingsResponse < Struct.new(
  :marker,
  :endpoint_settings)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


3277
3278
3279
3280
3281
3282
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3277

class DescribeEndpointSettingsResponse < Struct.new(
  :marker,
  :endpoint_settings)
  SENSITIVE = []
  include Aws::Structure
end