Class: Aws::DatabaseMigrationService::Types::DescribeEndpointsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeEndpointsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoints ⇒ Array<Types::Endpoint>
Endpoint description.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
Instance Attribute Details
#endpoints ⇒ Array<Types::Endpoint>
Endpoint description.
3382 3383 3384 3385 3386 3387 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3382 class DescribeEndpointsResponse < Struct.new( :marker, :endpoints) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond
the marker, up to the value specified by MaxRecords.
3382 3383 3384 3385 3386 3387 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3382 class DescribeEndpointsResponse < Struct.new( :marker, :endpoints) SENSITIVE = [] include Aws::Structure end |