Class: Aws::DatabaseMigrationService::Types::DescribeEventsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#durationInteger

The duration of the events to be listed.



3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3543

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end time for the events to be listed.



3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3543

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#event_categoriesArray<String>

A list of event categories for the source type that you’ve chosen.



3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3543

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

Filters applied to events. The only valid filter is replication-instance-id.



3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3543

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3543

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.



3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3543

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#source_identifierString

The identifier of an event source.



3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3543

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The type of DMS resource that generates events.

Valid values: replication-instance | replication-task



3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3543

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start time for the events to be listed.



3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3543

class DescribeEventsMessage < Struct.new(
  :source_identifier,
  :source_type,
  :start_time,
  :end_time,
  :duration,
  :event_categories,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end