Class: Aws::DatabaseMigrationService::Types::DescribeExtensionPackAssociationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Specifies the unique pagination token that makes it possible to display the next page of results. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

If Marker is returned by a previous response, there are more results available. The value of Marker is a unique pagination token for each page. To retrieve the next page, make the call again using the returned token and keeping all other arguments unchanged.

Returns:

  • (String)


3670
3671
3672
3673
3674
3675
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3670

class DescribeExtensionPackAssociationsResponse < Struct.new(
  :marker,
  :requests)
  SENSITIVE = []
  include Aws::Structure
end

#requestsArray<Types::SchemaConversionRequest>

A paginated list of extension pack installation requests.

DMS never populates the ExportSqlDetails field for this operation.

Returns:



3670
3671
3672
3673
3674
3675
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3670

class DescribeExtensionPackAssociationsResponse < Struct.new(
  :marker,
  :requests)
  SENSITIVE = []
  include Aws::Structure
end