Class: Aws::DatabaseMigrationService::Types::DescribeFleetAdvisorCollectorsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeFleetAdvisorCollectorsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
If you specify any of the following filters, the output includes information for only those collectors that meet the filter criteria:.
-
#max_records ⇒ Integer
Sets the maximum number of records returned in the response.
-
#next_token ⇒ String
If
NextTokenis returned by a previous response, there are more results available.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
If you specify any of the following filters, the output includes information for only those collectors that meet the filter criteria:
-
collector-referenced-id– The ID of the collector agent, for exampled4610ac5-e323-4ad9-bc50-eaf7249dfe9d. -
collector-name– The name of the collector agent.
An example is: describe-fleet-advisor-collectors --filter Name="collector-referenced-id",Values="d4610ac5-e323-4ad9-bc50-eaf7249dfe9d"
3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3703 class DescribeFleetAdvisorCollectorsRequest < Struct.new( :filters, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
Sets the maximum number of records returned in the response.
3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3703 class DescribeFleetAdvisorCollectorsRequest < Struct.new( :filters, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If NextToken is returned by a previous response, there are more
results available. The value of NextToken is a unique pagination
token for each page. Make the call again using the returned token to
retrieve the next page. Keep all other arguments unchanged.
3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3703 class DescribeFleetAdvisorCollectorsRequest < Struct.new( :filters, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |