Class: Aws::DatabaseMigrationService::Types::DescribeFleetAdvisorSchemaObjectSummaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::Filter>

If you specify any of the following filters, the output includes information for only those schema objects that meet the filter criteria:

  • schema-id – The ID of the schema, for example d4610ac5-e323-4ad9-bc50-eaf7249dfe9d.

^

Example: ‘describe-fleet-advisor-schema-object-summary –filter Name=“schema-id”,Values=“50”`

Returns:



3837
3838
3839
3840
3841
3842
3843
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3837

class DescribeFleetAdvisorSchemaObjectSummaryRequest < Struct.new(
  :filters,
  :max_records,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

End of support notice: On May 20, 2026, Amazon Web Services will end support for Amazon Web Services DMS Fleet Advisor;. After May 20, 2026, you will no longer be able to access the Amazon Web Services DMS Fleet Advisor; console or Amazon Web Services DMS Fleet Advisor; resources. For more information, see [Amazon Web Services DMS Fleet Advisor end of support].

Sets the maximum number of records returned in the response.

[1]: docs.aws.amazon.com/dms/latest/userguide/dms_fleet.advisor-end-of-support.html

Returns:

  • (Integer)


3837
3838
3839
3840
3841
3842
3843
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3837

class DescribeFleetAdvisorSchemaObjectSummaryRequest < Struct.new(
  :filters,
  :max_records,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If NextToken is returned by a previous response, there are more results available. The value of NextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged.

Returns:

  • (String)


3837
3838
3839
3840
3841
3842
3843
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3837

class DescribeFleetAdvisorSchemaObjectSummaryRequest < Struct.new(
  :filters,
  :max_records,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end