Class: Aws::DatabaseMigrationService::Types::DescribeInstanceProfilesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeInstanceProfilesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_profiles ⇒ Array<Types::InstanceProfile>
A description of instance profiles.
-
#marker ⇒ String
Specifies the unique pagination token that makes it possible to display the next page of results.
Instance Attribute Details
#instance_profiles ⇒ Array<Types::InstanceProfile>
A description of instance profiles.
4027 4028 4029 4030 4031 4032 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4027 class DescribeInstanceProfilesResponse < Struct.new( :marker, :instance_profiles) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Specifies the unique pagination token that makes it possible to
display the next page of results. If this parameter is specified,
the response includes only records beyond the marker, up to the
value specified by MaxRecords.
If Marker is returned by a previous response, there are more
results available. The value of Marker is a unique pagination
token for each page. To retrieve the next page, make the call again
using the returned token and keeping all other arguments unchanged.
4027 4028 4029 4030 4031 4032 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4027 class DescribeInstanceProfilesResponse < Struct.new( :marker, :instance_profiles) SENSITIVE = [] include Aws::Structure end |