Class: Aws::DatabaseMigrationService::Types::DescribeMetadataModelAssessmentsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::Filter>

The filters to apply to the metadata model assessment requests.

The following filter names are supported:

  • request-id – The request identifier.

  • status – The request status. Valid values: RECEIVED, IN_PROGRESS, SUCCESS, FAILED.

Returns:



4070
4071
4072
4073
4074
4075
4076
4077
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4070

class DescribeMetadataModelAssessmentsMessage < Struct.new(
  :migration_project_identifier,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Specifies the unique pagination token that makes it possible to display the next page of results. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

If Marker is returned by a previous response, there are more results available. The value of Marker is a unique pagination token for each page. To retrieve the next page, make the call again using the returned token and keeping all other arguments unchanged.

Returns:

  • (String)


4070
4071
4072
4073
4074
4075
4076
4077
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4070

class DescribeMetadataModelAssessmentsMessage < Struct.new(
  :migration_project_identifier,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, DMS includes a pagination token in the response so that you can retrieve the remaining results.

Returns:

  • (Integer)


4070
4071
4072
4073
4074
4075
4076
4077
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4070

class DescribeMetadataModelAssessmentsMessage < Struct.new(
  :migration_project_identifier,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#migration_project_identifierString

The migration project name or Amazon Resource Name (ARN).

Returns:

  • (String)


4070
4071
4072
4073
4074
4075
4076
4077
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4070

class DescribeMetadataModelAssessmentsMessage < Struct.new(
  :migration_project_identifier,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end