Class: Aws::DatabaseMigrationService::Types::DescribeMetadataModelAssessmentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeMetadataModelAssessmentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Specifies the unique pagination token that makes it possible to display the next page of results.
-
#requests ⇒ Array<Types::SchemaConversionRequest>
A paginated list of metadata model assessment requests.
Instance Attribute Details
#marker ⇒ String
Specifies the unique pagination token that makes it possible to
display the next page of results. If this parameter is specified,
the response includes only records beyond the marker, up to the
value specified by MaxRecords.
If Marker is returned by a previous response, there are more
results available. The value of Marker is a unique pagination
token for each page. To retrieve the next page, make the call again
using the returned token and keeping all other arguments unchanged.
4101 4102 4103 4104 4105 4106 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4101 class DescribeMetadataModelAssessmentsResponse < Struct.new( :marker, :requests) SENSITIVE = [] include Aws::Structure end |
#requests ⇒ Array<Types::SchemaConversionRequest>
A paginated list of metadata model assessment requests.
ExportSqlDetails field for this operation.
4101 4102 4103 4104 4105 4106 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4101 class DescribeMetadataModelAssessmentsResponse < Struct.new( :marker, :requests) SENSITIVE = [] include Aws::Structure end |