Class: Aws::DatabaseMigrationService::Types::DescribeMetadataModelChildrenMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

Specifies the unique pagination token that indicates where the next page should start. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


4153
4154
4155
4156
4157
4158
4159
4160
4161
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4153

class DescribeMetadataModelChildrenMessage < Struct.new(
  :selection_rules,
  :migration_project_identifier,
  :origin,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of metadata model children to include in the response. If more items exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.

Returns:

  • (Integer)


4153
4154
4155
4156
4157
4158
4159
4160
4161
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4153

class DescribeMetadataModelChildrenMessage < Struct.new(
  :selection_rules,
  :migration_project_identifier,
  :origin,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#migration_project_identifierString

The migration project name or Amazon Resource Name (ARN).

Returns:

  • (String)


4153
4154
4155
4156
4157
4158
4159
4160
4161
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4153

class DescribeMetadataModelChildrenMessage < Struct.new(
  :selection_rules,
  :migration_project_identifier,
  :origin,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#originString

Specifies whether to retrieve metadata from the source or target tree. Valid values: SOURCE | TARGET

Returns:

  • (String)


4153
4154
4155
4156
4157
4158
4159
4160
4161
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4153

class DescribeMetadataModelChildrenMessage < Struct.new(
  :selection_rules,
  :migration_project_identifier,
  :origin,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#selection_rulesString

A JSON string that identifies the metadata model whose children to retrieve. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.

Usage:

  • Accepts source or target selection rules depending on the Origin parameter. The server-name in the object locator must match the corresponding data provider.

  • Supports only explicit rule actions.

  • Exactly one rule is allowed.

Returns:

  • (String)


4153
4154
4155
4156
4157
4158
4159
4160
4161
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4153

class DescribeMetadataModelChildrenMessage < Struct.new(
  :selection_rules,
  :migration_project_identifier,
  :origin,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end