Class: Aws::DatabaseMigrationService::Types::DescribeMetadataModelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeMetadataModelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#definition ⇒ String
The SQL text of the metadata model.
-
#metadata_model_name ⇒ String
The name of the metadata model.
-
#metadata_model_type ⇒ String
The type of the metadata model.
-
#target_metadata_models ⇒ Array<Types::MetadataModelReference>
A list of counterpart metadata models in the target.
Instance Attribute Details
#definition ⇒ String
The SQL text of the metadata model. This field might not be populated for some metadata models.
4608 4609 4610 4611 4612 4613 4614 4615 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4608 class DescribeMetadataModelResponse < Struct.new( :metadata_model_name, :metadata_model_type, :target_metadata_models, :definition) SENSITIVE = [] include Aws::Structure end |
#metadata_model_name ⇒ String
The name of the metadata model.
4608 4609 4610 4611 4612 4613 4614 4615 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4608 class DescribeMetadataModelResponse < Struct.new( :metadata_model_name, :metadata_model_type, :target_metadata_models, :definition) SENSITIVE = [] include Aws::Structure end |
#metadata_model_type ⇒ String
The type of the metadata model.
4608 4609 4610 4611 4612 4613 4614 4615 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4608 class DescribeMetadataModelResponse < Struct.new( :metadata_model_name, :metadata_model_type, :target_metadata_models, :definition) SENSITIVE = [] include Aws::Structure end |
#target_metadata_models ⇒ Array<Types::MetadataModelReference>
A list of counterpart metadata models in the target. This field is populated only when Origin is SOURCE and after the object has been converted by DMS Schema Conversion.
4608 4609 4610 4611 4612 4613 4614 4615 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4608 class DescribeMetadataModelResponse < Struct.new( :metadata_model_name, :metadata_model_type, :target_metadata_models, :definition) SENSITIVE = [] include Aws::Structure end |