Class: Aws::DatabaseMigrationService::Types::DescribeMigrationProjectsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeMigrationProjectsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Specifies the unique pagination token that makes it possible to display the next page of results.
-
#migration_projects ⇒ Array<Types::MigrationProject>
A description of migration projects.
Instance Attribute Details
#marker ⇒ String
Specifies the unique pagination token that makes it possible to
display the next page of results. If this parameter is specified,
the response includes only records beyond the marker, up to the
value specified by MaxRecords.
If Marker is returned by a previous response, there are more
results available. The value of Marker is a unique pagination
token for each page. To retrieve the next page, make the call again
using the returned token and keeping all other arguments unchanged.
4684 4685 4686 4687 4688 4689 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4684 class DescribeMigrationProjectsResponse < Struct.new( :marker, :migration_projects) SENSITIVE = [] include Aws::Structure end |
#migration_projects ⇒ Array<Types::MigrationProject>
A description of migration projects.
4684 4685 4686 4687 4688 4689 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4684 class DescribeMigrationProjectsResponse < Struct.new( :marker, :migration_projects) SENSITIVE = [] include Aws::Structure end |