Class: Aws::DatabaseMigrationService::Types::DescribeRecommendationLimitationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#limitationsArray<Types::Limitation>

The list of limitations for recommendations of target Amazon Web Services engines.

Returns:



4841
4842
4843
4844
4845
4846
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4841

class DescribeRecommendationLimitationsResponse < Struct.new(
  :next_token,
  :limitations)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The unique pagination token returned for you to pass to a subsequent request. Fleet Advisor returns this token when the number of records in the response is greater than the MaxRecords value. To retrieve the next page, make the call again using the returned token and keeping all other arguments unchanged.

Returns:

  • (String)


4841
4842
4843
4844
4845
4846
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4841

class DescribeRecommendationLimitationsResponse < Struct.new(
  :next_token,
  :limitations)
  SENSITIVE = []
  include Aws::Structure
end