Class: Aws::DatabaseMigrationService::Types::DescribeReplicationTaskAssessmentResultsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


5224
5225
5226
5227
5228
5229
5230
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5224

class DescribeReplicationTaskAssessmentResultsMessage < Struct.new(
  :replication_task_arn,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.

Returns:

  • (Integer)


5224
5225
5226
5227
5228
5229
5230
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5224

class DescribeReplicationTaskAssessmentResultsMessage < Struct.new(
  :replication_task_arn,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#replication_task_arnString

The Amazon Resource Name (ARN) string that uniquely identifies the task. When this input parameter is specified, the API returns only one result and ignore the values of the MaxRecords and Marker parameters.

Returns:

  • (String)


5224
5225
5226
5227
5228
5229
5230
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5224

class DescribeReplicationTaskAssessmentResultsMessage < Struct.new(
  :replication_task_arn,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end