Class: Aws::DatabaseMigrationService::Types::DocDbSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DocDbSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides information that defines a DocumentDB endpoint.
Constant Summary collapse
- SENSITIVE =
[:password]
Instance Attribute Summary collapse
-
#database_name ⇒ String
The database name on the DocumentDB source endpoint.
-
#docs_to_investigate ⇒ Integer
Indicates the number of documents to preview to determine the document organization.
-
#extract_doc_id ⇒ Boolean
Specifies the document ID.
-
#kms_key_id ⇒ String
The KMS key identifier that is used to encrypt the content on the replication instance.
-
#nesting_level ⇒ String
Specifies either document or table mode.
-
#password ⇒ String
The password for the user account you use to access the DocumentDB source endpoint.
-
#port ⇒ Integer
The port value for the DocumentDB source endpoint.
-
#replicate_shard_collections ⇒ Boolean
If
true, DMS replicates data to shard collections. -
#secrets_manager_access_role_arn ⇒ String
The full Amazon Resource Name (ARN) of the IAM role that specifies DMS as the trusted entity and grants the required permissions to access the value in
SecretsManagerSecret. -
#secrets_manager_secret_id ⇒ String
The full ARN, partial ARN, or friendly name of the
SecretsManagerSecretthat contains the DocumentDB endpoint connection details. -
#server_name ⇒ String
The name of the server on the DocumentDB source endpoint.
-
#use_update_look_up ⇒ Boolean
If
true, DMS retrieves the entire document from the DocumentDB source during migration. -
#username ⇒ String
The user name you use to access the DocumentDB source endpoint.
Instance Attribute Details
#database_name ⇒ String
The database name on the DocumentDB source endpoint.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#docs_to_investigate ⇒ Integer
Indicates the number of documents to preview to determine the document organization. Use this setting when NestingLevel is set to ‘“one”`.
Must be a positive value greater than 0. Default value is 1000.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#extract_doc_id ⇒ Boolean
Specifies the document ID. Use this setting when NestingLevel is set to ‘“none”`.
Default value is ‘“false”`.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#kms_key_id ⇒ String
The KMS key identifier that is used to encrypt the content on the replication instance. If you don’t specify a value for the KmsKeyId parameter, then DMS uses your default encryption key. KMS creates the default encryption key for your Amazon Web Services account. Your Amazon Web Services account has a different default encryption key for each Amazon Web Services Region.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#nesting_level ⇒ String
Specifies either document or table mode.
Default value is ‘“none”`. Specify `“none”` to use document mode. Specify `“one”` to use table mode.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#password ⇒ String
The password for the user account you use to access the DocumentDB source endpoint.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#port ⇒ Integer
The port value for the DocumentDB source endpoint.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#replicate_shard_collections ⇒ Boolean
If true, DMS replicates data to shard collections. DMS only uses this setting if the target endpoint is a DocumentDB elastic cluster.
When this setting is true, note the following:
-
You must set
TargetTablePrepModetonothing. -
DMS automatically sets
useUpdateLookuptofalse.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#secrets_manager_access_role_arn ⇒ String
The full Amazon Resource Name (ARN) of the IAM role that specifies DMS as the trusted entity and grants the required permissions to access the value in SecretsManagerSecret. The role must allow the iam:PassRole action. SecretsManagerSecret has the value of the Amazon Web Services Secrets Manager secret that allows access to the DocumentDB endpoint.
<note markdown=“1”> You can specify one of two sets of values for these permissions. You can specify the values for this setting and SecretsManagerSecretId. Or you can specify clear-text values for UserName, Password, ServerName, and Port. You can’t specify both. For more information on creating this SecretsManagerSecret and the SecretsManagerAccessRoleArn and SecretsManagerSecretId required to access it, see [Using secrets to access Database Migration Service resources] in the *Database Migration Service User Guide*.
</note>
[1]: docs.aws.amazon.com/dms/latest/userguide/CHAP_Security.html#security-iam-secretsmanager
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#secrets_manager_secret_id ⇒ String
The full ARN, partial ARN, or friendly name of the SecretsManagerSecret that contains the DocumentDB endpoint connection details.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#server_name ⇒ String
The name of the server on the DocumentDB source endpoint.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#use_update_look_up ⇒ Boolean
If true, DMS retrieves the entire document from the DocumentDB source during migration. This may cause a migration failure if the server response exceeds bandwidth limits. To fetch only updates and deletes during migration, set this parameter to false.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |
#username ⇒ String
The user name you use to access the DocumentDB source endpoint.
5617 5618 5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 5617 class DocDbSettings < Struct.new( :username, :password, :server_name, :port, :database_name, :nesting_level, :extract_doc_id, :docs_to_investigate, :kms_key_id, :secrets_manager_access_role_arn, :secrets_manager_secret_id, :use_update_look_up, :replicate_shard_collections) SENSITIVE = [:password] include Aws::Structure end |