Class: Aws::DatabaseMigrationService::Types::ErrorDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Note:

ErrorDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ErrorDetails corresponding to the set member.

Provides error information about a project.

Defined Under Namespace

Classes: DefaultErrorDetails, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_error_detailsTypes::DefaultErrorDetails

Error information about a project.



6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6209

class ErrorDetails < Struct.new(
  :default_error_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DefaultErrorDetails < ErrorDetails; end
  class Unknown < ErrorDetails; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



6209
6210
6211
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6209

def unknown
  @unknown
end