Class: Aws::DatabaseMigrationService::Types::ExportMetadataModelAssessmentMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::ExportMetadataModelAssessmentMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assessment_report_types ⇒ Array<String>
The file format of the assessment file.
-
#file_name ⇒ String
The name of the assessment file to create in your Amazon S3 bucket.
-
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
-
#selection_rules ⇒ String
A JSON string that identifies the metadata models to export a conversion assessment report for.
Instance Attribute Details
#assessment_report_types ⇒ Array<String>
The file format of the assessment file.
6387 6388 6389 6390 6391 6392 6393 6394 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6387 class ExportMetadataModelAssessmentMessage < Struct.new( :migration_project_identifier, :selection_rules, :file_name, :assessment_report_types) SENSITIVE = [] include Aws::Structure end |
#file_name ⇒ String
The name of the assessment file to create in your Amazon S3 bucket.
6387 6388 6389 6390 6391 6392 6393 6394 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6387 class ExportMetadataModelAssessmentMessage < Struct.new( :migration_project_identifier, :selection_rules, :file_name, :assessment_report_types) SENSITIVE = [] include Aws::Structure end |
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
6387 6388 6389 6390 6391 6392 6393 6394 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6387 class ExportMetadataModelAssessmentMessage < Struct.new( :migration_project_identifier, :selection_rules, :file_name, :assessment_report_types) SENSITIVE = [] include Aws::Structure end |
#selection_rules ⇒ String
A JSON string that identifies the metadata models to export a conversion assessment report for. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.
Usage:
-
Accepts only source selection rules, where
server-namein the object locator matches the source data provider. -
Supports only
explicitrule actions.
6387 6388 6389 6390 6391 6392 6393 6394 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6387 class ExportMetadataModelAssessmentMessage < Struct.new( :migration_project_identifier, :selection_rules, :file_name, :assessment_report_types) SENSITIVE = [] include Aws::Structure end |