Class: Aws::DatabaseMigrationService::Types::GetTargetSelectionRulesMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#migration_project_identifierString

The migration project name or Amazon Resource Name (ARN).

Returns:

  • (String)


6726
6727
6728
6729
6730
6731
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6726

class GetTargetSelectionRulesMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules)
  SENSITIVE = []
  include Aws::Structure
end

#selection_rulesString

A JSON string that contains the source selection rules to convert into their target counterparts. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.

Usage:

  • Accepts only source selection rules, where server-name in the object locator matches the source data provider.

  • Supports only explicit rule actions.

  • Does not support category-name in the object locator.

  • Up to 10 rules are allowed.

Returns:

  • (String)


6726
6727
6728
6729
6730
6731
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6726

class GetTargetSelectionRulesMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules)
  SENSITIVE = []
  include Aws::Structure
end