Class: Aws::DatabaseMigrationService::Types::IbmDb2LuwDataProviderSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::IbmDb2LuwDataProviderSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides information about an IBM DB2 LUW data provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate used for SSL connection.
-
#database_name ⇒ String
The database name on the DB2 LUW data provider.
-
#encryption_algorithm ⇒ Integer
The encryption algorithm used for securing the connection to the IBM DB2 LUW database server.
-
#port ⇒ Integer
The port value for the DB2 LUW data provider.
-
#s3_access_role_arn ⇒ String
The ARN for the role the application uses to access its Amazon S3 bucket.
-
#s3_path ⇒ String
The path for the Amazon S3 bucket that the application uses for accessing the user-defined schema.
-
#security_mechanism ⇒ Integer
The security mechanism used for authenticating the connection to the IBM DB2 LUW database server.
-
#server_name ⇒ String
The name of the DB2 LUW server.
-
#ssl_mode ⇒ String
The SSL mode used to connect to the DB2 LUW data provider.
Instance Attribute Details
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate used for SSL connection.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6910 class IbmDb2LuwDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :encryption_algorithm, :security_mechanism, :s3_path, :s3_access_role_arn) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database name on the DB2 LUW data provider.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6910 class IbmDb2LuwDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :encryption_algorithm, :security_mechanism, :s3_path, :s3_access_role_arn) SENSITIVE = [] include Aws::Structure end |
#encryption_algorithm ⇒ Integer
The encryption algorithm used for securing the connection to the IBM DB2 LUW database server. You can provide an integer value corresponding to a specific encryption algorithm, or leave this parameter empty to use the default behavior.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6910 class IbmDb2LuwDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :encryption_algorithm, :security_mechanism, :s3_path, :s3_access_role_arn) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port value for the DB2 LUW data provider.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6910 class IbmDb2LuwDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :encryption_algorithm, :security_mechanism, :s3_path, :s3_access_role_arn) SENSITIVE = [] include Aws::Structure end |
#s3_access_role_arn ⇒ String
The ARN for the role the application uses to access its Amazon S3 bucket.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6910 class IbmDb2LuwDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :encryption_algorithm, :security_mechanism, :s3_path, :s3_access_role_arn) SENSITIVE = [] include Aws::Structure end |
#s3_path ⇒ String
The path for the Amazon S3 bucket that the application uses for accessing the user-defined schema.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6910 class IbmDb2LuwDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :encryption_algorithm, :security_mechanism, :s3_path, :s3_access_role_arn) SENSITIVE = [] include Aws::Structure end |
#security_mechanism ⇒ Integer
The security mechanism used for authenticating the connection to the IBM DB2 LUW database server. You can provide an integer value corresponding to a specific security mechanism, or leave this parameter empty to use the default behavior.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6910 class IbmDb2LuwDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :encryption_algorithm, :security_mechanism, :s3_path, :s3_access_role_arn) SENSITIVE = [] include Aws::Structure end |
#server_name ⇒ String
The name of the DB2 LUW server.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6910 class IbmDb2LuwDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :encryption_algorithm, :security_mechanism, :s3_path, :s3_access_role_arn) SENSITIVE = [] include Aws::Structure end |
#ssl_mode ⇒ String
The SSL mode used to connect to the DB2 LUW data provider. The
default value is none. Valid Values: none and verify-ca.
6910 6911 6912 6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6910 class IbmDb2LuwDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :encryption_algorithm, :security_mechanism, :s3_path, :s3_access_role_arn) SENSITIVE = [] include Aws::Structure end |