Class: Aws::DatabaseMigrationService::Types::InstanceProfile

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Provides information that defines an instance profile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone where the instance profile runs.



7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7094

class InstanceProfile < Struct.new(
  :instance_profile_arn,
  :availability_zone,
  :kms_key_arn,
  :publicly_accessible,
  :network_type,
  :instance_profile_name,
  :description,
  :instance_profile_creation_time,
  :subnet_group_identifier,
  :vpc_security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the instance profile. Descriptions can have up to 31 characters. A description can contain only ASCII letters, digits, and hyphens ('-'). Also, it can't end with a hyphen or contain two consecutive hyphens, and can only begin with a letter.



7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7094

class InstanceProfile < Struct.new(
  :instance_profile_arn,
  :availability_zone,
  :kms_key_arn,
  :publicly_accessible,
  :network_type,
  :instance_profile_name,
  :description,
  :instance_profile_creation_time,
  :subnet_group_identifier,
  :vpc_security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#instance_profile_arnString

The Amazon Resource Name (ARN) string that uniquely identifies the instance profile.



7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7094

class InstanceProfile < Struct.new(
  :instance_profile_arn,
  :availability_zone,
  :kms_key_arn,
  :publicly_accessible,
  :network_type,
  :instance_profile_name,
  :description,
  :instance_profile_creation_time,
  :subnet_group_identifier,
  :vpc_security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#instance_profile_creation_timeTime

The time the instance profile was created.



7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7094

class InstanceProfile < Struct.new(
  :instance_profile_arn,
  :availability_zone,
  :kms_key_arn,
  :publicly_accessible,
  :network_type,
  :instance_profile_name,
  :description,
  :instance_profile_creation_time,
  :subnet_group_identifier,
  :vpc_security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#instance_profile_nameString

The user-friendly name for the instance profile.



7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7094

class InstanceProfile < Struct.new(
  :instance_profile_arn,
  :availability_zone,
  :kms_key_arn,
  :publicly_accessible,
  :network_type,
  :instance_profile_name,
  :description,
  :instance_profile_creation_time,
  :subnet_group_identifier,
  :vpc_security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the KMS key that is used to encrypt the connection parameters for the instance profile.

If you don't specify a value for the KmsKeyArn parameter, then DMS uses an Amazon Web Services owned encryption key to encrypt your resources.



7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7094

class InstanceProfile < Struct.new(
  :instance_profile_arn,
  :availability_zone,
  :kms_key_arn,
  :publicly_accessible,
  :network_type,
  :instance_profile_name,
  :description,
  :instance_profile_creation_time,
  :subnet_group_identifier,
  :vpc_security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#network_typeString

Specifies the network type for the instance profile. A value of IPV4 represents an instance profile with IPv4 network type and only supports IPv4 addressing. A value of IPV6 represents an instance profile with IPv6 network type and only supports IPv6 addressing. A value of DUAL represents an instance profile with dual network type that supports IPv4 and IPv6 addressing.



7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7094

class InstanceProfile < Struct.new(
  :instance_profile_arn,
  :availability_zone,
  :kms_key_arn,
  :publicly_accessible,
  :network_type,
  :instance_profile_name,
  :description,
  :instance_profile_creation_time,
  :subnet_group_identifier,
  :vpc_security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#publicly_accessibleBoolean

Specifies the accessibility options for the instance profile. A value of true represents an instance profile with a public IP address. A value of false represents an instance profile with a private IP address. The default value is true.



7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7094

class InstanceProfile < Struct.new(
  :instance_profile_arn,
  :availability_zone,
  :kms_key_arn,
  :publicly_accessible,
  :network_type,
  :instance_profile_name,
  :description,
  :instance_profile_creation_time,
  :subnet_group_identifier,
  :vpc_security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_group_identifierString

The identifier of the subnet group that is associated with the instance profile.



7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7094

class InstanceProfile < Struct.new(
  :instance_profile_arn,
  :availability_zone,
  :kms_key_arn,
  :publicly_accessible,
  :network_type,
  :instance_profile_name,
  :description,
  :instance_profile_creation_time,
  :subnet_group_identifier,
  :vpc_security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_security_groupsArray<String>

The VPC security groups that are used with the instance profile. The VPC security group must work with the VPC containing the instance profile.



7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
7104
7105
7106
7107
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7094

class InstanceProfile < Struct.new(
  :instance_profile_arn,
  :availability_zone,
  :kms_key_arn,
  :publicly_accessible,
  :network_type,
  :instance_profile_name,
  :description,
  :instance_profile_creation_time,
  :subnet_group_identifier,
  :vpc_security_groups)
  SENSITIVE = []
  include Aws::Structure
end