Class: Aws::DatabaseMigrationService::Types::Limitation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Provides information about the limitations of target Amazon Web Services engines.

Your source database might include features that the target Amazon Web Services engine doesn't support. Fleet Advisor lists these features as limitations. You should consider these limitations during database migration. For each limitation, Fleet Advisor recommends an action that you can take to address or avoid this limitation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#database_idString

The identifier of the source database.

Returns:

  • (String)


7638
7639
7640
7641
7642
7643
7644
7645
7646
7647
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7638

class Limitation < Struct.new(
  :database_id,
  :engine_name,
  :name,
  :description,
  :impact,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the limitation. Provides additional information about the limitation, and includes recommended actions that you can take to address or avoid this limitation.

Returns:

  • (String)


7638
7639
7640
7641
7642
7643
7644
7645
7646
7647
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7638

class Limitation < Struct.new(
  :database_id,
  :engine_name,
  :name,
  :description,
  :impact,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#engine_nameString

The name of the target engine that Fleet Advisor should use in the target engine recommendation. Valid values include "rds-aurora-mysql", "rds-aurora-postgresql", "rds-mysql", "rds-oracle", "rds-sql-server", and "rds-postgresql".

Returns:

  • (String)


7638
7639
7640
7641
7642
7643
7644
7645
7646
7647
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7638

class Limitation < Struct.new(
  :database_id,
  :engine_name,
  :name,
  :description,
  :impact,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#impactString

The impact of the limitation. You can use this parameter to prioritize limitations that you want to address. Valid values include "Blocker", "High", "Medium", and "Low".

Returns:

  • (String)


7638
7639
7640
7641
7642
7643
7644
7645
7646
7647
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7638

class Limitation < Struct.new(
  :database_id,
  :engine_name,
  :name,
  :description,
  :impact,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the limitation. Describes unsupported database features, migration action items, and other limitations.

Returns:

  • (String)


7638
7639
7640
7641
7642
7643
7644
7645
7646
7647
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7638

class Limitation < Struct.new(
  :database_id,
  :engine_name,
  :name,
  :description,
  :impact,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the limitation, such as action required, upgrade required, and limited feature.

Returns:

  • (String)


7638
7639
7640
7641
7642
7643
7644
7645
7646
7647
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7638

class Limitation < Struct.new(
  :database_id,
  :engine_name,
  :name,
  :description,
  :impact,
  :type)
  SENSITIVE = []
  include Aws::Structure
end