Class: Aws::DatabaseMigrationService::Types::MetadataModelReference

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

A reference to a metadata model, including its name and selection rules for location identification.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metadata_model_nameString

The name of the metadata model.

Returns:

  • (String)


7776
7777
7778
7779
7780
7781
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7776

class MetadataModelReference < Struct.new(
  :metadata_model_name,
  :selection_rules)
  SENSITIVE = []
  include Aws::Structure
end

#selection_rulesString

A JSON string that identifies this metadata model in the metadata tree. For the selection rule format, see Selection rules in DMS Schema Conversion.

Usage:

  • You can pass this value as the SelectionRules parameter to any operation that accepts selection rules, such as DescribeMetadataModel, StartMetadataModelConversion, and others.

^

Returns:

  • (String)


7776
7777
7778
7779
7780
7781
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7776

class MetadataModelReference < Struct.new(
  :metadata_model_name,
  :selection_rules)
  SENSITIVE = []
  include Aws::Structure
end