Class: Aws::DatabaseMigrationService::Types::MigrationProject
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::MigrationProject
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides information that defines a migration project.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A user-friendly description of the migration project.
-
#instance_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the instance profile for your migration project.
-
#instance_profile_name ⇒ String
The name of the associated instance profile.
-
#migration_project_arn ⇒ String
The ARN string that uniquely identifies the migration project.
-
#migration_project_creation_time ⇒ Time
The time when the migration project was created.
-
#migration_project_name ⇒ String
The name of the migration project.
-
#schema_conversion_application_attributes ⇒ Types::SCApplicationAttributes
The schema conversion application attributes, including the Amazon S3 bucket name and Amazon S3 role ARN.
-
#source_data_provider_descriptors ⇒ Array<Types::DataProviderDescriptor>
Information about the source data provider, including the name or ARN, and Secrets Manager parameters.
-
#target_data_provider_descriptors ⇒ Array<Types::DataProviderDescriptor>
Information about the target data provider, including the name or ARN, and Secrets Manager parameters.
-
#transformation_rules ⇒ String
The transformation rules for the migration project in JSON format.
Instance Attribute Details
#description ⇒ String
A user-friendly description of the migration project.
8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8059 class MigrationProject < Struct.new( :migration_project_name, :migration_project_arn, :migration_project_creation_time, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_arn, :instance_profile_name, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#instance_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the instance profile for your migration project.
8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8059 class MigrationProject < Struct.new( :migration_project_name, :migration_project_arn, :migration_project_creation_time, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_arn, :instance_profile_name, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#instance_profile_name ⇒ String
The name of the associated instance profile.
8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8059 class MigrationProject < Struct.new( :migration_project_name, :migration_project_arn, :migration_project_creation_time, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_arn, :instance_profile_name, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#migration_project_arn ⇒ String
The ARN string that uniquely identifies the migration project.
8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8059 class MigrationProject < Struct.new( :migration_project_name, :migration_project_arn, :migration_project_creation_time, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_arn, :instance_profile_name, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#migration_project_creation_time ⇒ Time
The time when the migration project was created.
8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8059 class MigrationProject < Struct.new( :migration_project_name, :migration_project_arn, :migration_project_creation_time, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_arn, :instance_profile_name, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#migration_project_name ⇒ String
The name of the migration project.
8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8059 class MigrationProject < Struct.new( :migration_project_name, :migration_project_arn, :migration_project_creation_time, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_arn, :instance_profile_name, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#schema_conversion_application_attributes ⇒ Types::SCApplicationAttributes
The schema conversion application attributes, including the Amazon S3 bucket name and Amazon S3 role ARN.
8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8059 class MigrationProject < Struct.new( :migration_project_name, :migration_project_arn, :migration_project_creation_time, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_arn, :instance_profile_name, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#source_data_provider_descriptors ⇒ Array<Types::DataProviderDescriptor>
Information about the source data provider, including the name or ARN, and Secrets Manager parameters.
8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8059 class MigrationProject < Struct.new( :migration_project_name, :migration_project_arn, :migration_project_creation_time, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_arn, :instance_profile_name, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#target_data_provider_descriptors ⇒ Array<Types::DataProviderDescriptor>
Information about the target data provider, including the name or ARN, and Secrets Manager parameters.
8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8059 class MigrationProject < Struct.new( :migration_project_name, :migration_project_arn, :migration_project_creation_time, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_arn, :instance_profile_name, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#transformation_rules ⇒ String
The transformation rules for the migration project in JSON format. Transformation rules let you customize how DMS Schema Conversion converts your source database objects, including renaming, adding prefixes or suffixes, and changing data types. For the transformation rule format and examples, see Transformation rules in DMS Schema Conversion.
8059 8060 8061 8062 8063 8064 8065 8066 8067 8068 8069 8070 8071 8072 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8059 class MigrationProject < Struct.new( :migration_project_name, :migration_project_arn, :migration_project_creation_time, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_arn, :instance_profile_name, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |