Class: Aws::DatabaseMigrationService::Types::ModifyConversionConfigurationMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#conversion_configurationString

A JSON string that contains the schema conversion settings to update. For the format and available settings, see Specifying schema conversion settings for migration projects.

Usage:

  • Include only the sections and keys to change. The operation merges supplied values with the existing configuration.

^

Returns:

  • (String)


8097
8098
8099
8100
8101
8102
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8097

class ModifyConversionConfigurationMessage < Struct.new(
  :migration_project_identifier,
  :conversion_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#migration_project_identifierString

The migration project name or Amazon Resource Name (ARN).

Returns:

  • (String)


8097
8098
8099
8100
8101
8102
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8097

class ModifyConversionConfigurationMessage < Struct.new(
  :migration_project_identifier,
  :conversion_configuration)
  SENSITIVE = []
  include Aws::Structure
end