Class: Aws::DatabaseMigrationService::Types::ModifyDataProviderMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::ModifyDataProviderMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_provider_identifier ⇒ String
The identifier of the data provider.
-
#data_provider_name ⇒ String
The name of the data provider.
-
#description ⇒ String
A user-friendly description of the data provider.
-
#engine ⇒ String
The type of database engine for the data provider.
-
#exact_settings ⇒ Boolean
If this attribute is Y, the current call to
ModifyDataProviderreplaces all existing data provider settings with the exact settings that you specify in this call. -
#settings ⇒ Types::DataProviderSettings
The settings in JSON format for a data provider.
-
#virtual ⇒ Boolean
Indicates whether the data provider is virtual.
Instance Attribute Details
#data_provider_identifier ⇒ String
The identifier of the data provider. Identifiers must begin with a letter and must contain only ASCII letters, digits, and hyphens. They can't end with a hyphen, or contain two consecutive hyphens.
8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8231 class ModifyDataProviderMessage < Struct.new( :data_provider_identifier, :data_provider_name, :description, :engine, :virtual, :exact_settings, :settings) SENSITIVE = [] include Aws::Structure end |
#data_provider_name ⇒ String
The name of the data provider.
8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8231 class ModifyDataProviderMessage < Struct.new( :data_provider_identifier, :data_provider_name, :description, :engine, :virtual, :exact_settings, :settings) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A user-friendly description of the data provider.
8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8231 class ModifyDataProviderMessage < Struct.new( :data_provider_identifier, :data_provider_name, :description, :engine, :virtual, :exact_settings, :settings) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The type of database engine for the data provider.
Valid values: aurora, aurora-postgresql, db2, db2-zos,
docdb, mariadb, mongodb, mysql, oracle, postgres,
redshift, sqlserver, and sybase. A value of aurora
represents Amazon Aurora MySQL-Compatible Edition.
8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8231 class ModifyDataProviderMessage < Struct.new( :data_provider_identifier, :data_provider_name, :description, :engine, :virtual, :exact_settings, :settings) SENSITIVE = [] include Aws::Structure end |
#exact_settings ⇒ Boolean
If this attribute is Y, the current call to ModifyDataProvider
replaces all existing data provider settings with the exact settings
that you specify in this call. If this attribute is N, the current
call to ModifyDataProvider does two things:
-
It replaces any data provider settings that already exist with new values, for settings with the same names.
-
It creates new data provider settings that you specify in the call, for settings with different names.
8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8231 class ModifyDataProviderMessage < Struct.new( :data_provider_identifier, :data_provider_name, :description, :engine, :virtual, :exact_settings, :settings) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Types::DataProviderSettings
The settings in JSON format for a data provider.
8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8231 class ModifyDataProviderMessage < Struct.new( :data_provider_identifier, :data_provider_name, :description, :engine, :virtual, :exact_settings, :settings) SENSITIVE = [] include Aws::Structure end |
#virtual ⇒ Boolean
Indicates whether the data provider is virtual.
8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8231 class ModifyDataProviderMessage < Struct.new( :data_provider_identifier, :data_provider_name, :description, :engine, :virtual, :exact_settings, :settings) SENSITIVE = [] include Aws::Structure end |