Class: Aws::DatabaseMigrationService::Types::ModifyMigrationProjectMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::ModifyMigrationProjectMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A user-friendly description of the migration project.
-
#instance_profile_identifier ⇒ String
The name or Amazon Resource Name (ARN) for the instance profile.
-
#migration_project_identifier ⇒ String
The identifier of the migration project.
-
#migration_project_name ⇒ String
A user-friendly name for the migration project.
-
#schema_conversion_application_attributes ⇒ Types::SCApplicationAttributes
The schema conversion application attributes, including the Amazon S3 bucket name and Amazon S3 role ARN.
-
#source_data_provider_descriptors ⇒ Array<Types::DataProviderDescriptorDefinition>
Information about the source data provider, including the name, ARN, and Amazon Web Services Secrets Manager parameters.
-
#target_data_provider_descriptors ⇒ Array<Types::DataProviderDescriptorDefinition>
Information about the target data provider, including the name, ARN, and Amazon Web Services Secrets Manager parameters.
-
#transformation_rules ⇒ String
A JSON string that specifies the transformation rules for the migration project.
Instance Attribute Details
#description ⇒ String
A user-friendly description of the migration project.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8788 class ModifyMigrationProjectMessage < Struct.new( :migration_project_identifier, :migration_project_name, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_identifier, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#instance_profile_identifier ⇒ String
The name or Amazon Resource Name (ARN) for the instance profile.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8788 class ModifyMigrationProjectMessage < Struct.new( :migration_project_identifier, :migration_project_name, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_identifier, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#migration_project_identifier ⇒ String
The identifier of the migration project. Identifiers must begin with a letter and must contain only ASCII letters, digits, and hyphens. They can't end with a hyphen, or contain two consecutive hyphens.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8788 class ModifyMigrationProjectMessage < Struct.new( :migration_project_identifier, :migration_project_name, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_identifier, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#migration_project_name ⇒ String
A user-friendly name for the migration project.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8788 class ModifyMigrationProjectMessage < Struct.new( :migration_project_identifier, :migration_project_name, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_identifier, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#schema_conversion_application_attributes ⇒ Types::SCApplicationAttributes
The schema conversion application attributes, including the Amazon S3 bucket name and Amazon S3 role ARN.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8788 class ModifyMigrationProjectMessage < Struct.new( :migration_project_identifier, :migration_project_name, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_identifier, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#source_data_provider_descriptors ⇒ Array<Types::DataProviderDescriptorDefinition>
Information about the source data provider, including the name, ARN, and Amazon Web Services Secrets Manager parameters.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8788 class ModifyMigrationProjectMessage < Struct.new( :migration_project_identifier, :migration_project_name, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_identifier, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#target_data_provider_descriptors ⇒ Array<Types::DataProviderDescriptorDefinition>
Information about the target data provider, including the name, ARN, and Amazon Web Services Secrets Manager parameters.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8788 class ModifyMigrationProjectMessage < Struct.new( :migration_project_identifier, :migration_project_name, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_identifier, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |
#transformation_rules ⇒ String
A JSON string that specifies the transformation rules for the migration project. Transformation rules let you customize how DMS Schema Conversion converts your source database objects, including renaming, adding prefixes or suffixes, and changing data types. For the transformation rule format and examples, see Transformation rules in DMS Schema Conversion.
8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8788 class ModifyMigrationProjectMessage < Struct.new( :migration_project_identifier, :migration_project_name, :source_data_provider_descriptors, :target_data_provider_descriptors, :instance_profile_identifier, :transformation_rules, :description, :schema_conversion_application_attributes) SENSITIVE = [] include Aws::Structure end |