Class: Aws::DatabaseMigrationService::Types::ModifyReplicationTaskMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::ModifyReplicationTaskMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cdc_start_position ⇒ String
Indicates when you want a change data capture (CDC) operation to start.
-
#cdc_start_time ⇒ Time
Indicates the start time for a change data capture (CDC) operation.
-
#cdc_stop_position ⇒ String
Indicates when you want a change data capture (CDC) operation to stop.
-
#migration_type ⇒ String
The migration type.
-
#replication_task_arn ⇒ String
The Amazon Resource Name (ARN) of the replication task.
-
#replication_task_identifier ⇒ String
The replication task identifier.
-
#replication_task_settings ⇒ String
JSON file that contains settings for the task, such as task metadata settings.
-
#table_mappings ⇒ String
When using the CLI or boto3, provide the path of the JSON file that contains the table mappings.
-
#task_data ⇒ String
Supplemental information that the task requires to migrate the data for certain source and target endpoints.
Instance Attribute Details
#cdc_start_position ⇒ String
Indicates when you want a change data capture (CDC) operation to start. Use either CdcStartPosition or CdcStartTime to specify when you want a CDC operation to start. Specifying both values results in an error.
The value can be in date, checkpoint, or LSN/SCN format.
Date Example: --cdc-start-position “2018-03-08T12:12:12”
Checkpoint Example: --cdc-start-position "checkpoint:V1#27#mysql-bin-changelog.157832:1975:-1:2002:677883278264080:mysql-bin-changelog.157832:1876#0#0#*#0#93"
LSN Example: --cdc-start-position “mysql-bin-changelog.000024:373”
slotName extra connection attribute to the name of this logical
replication slot. For more information, see Extra Connection
Attributes When Using PostgreSQL as a Source for DMS.
9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9150 class ModifyReplicationTaskMessage < Struct.new( :replication_task_arn, :replication_task_identifier, :migration_type, :table_mappings, :replication_task_settings, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :task_data) SENSITIVE = [] include Aws::Structure end |
#cdc_start_time ⇒ Time
Indicates the start time for a change data capture (CDC) operation. Use either CdcStartTime or CdcStartPosition to specify when you want a CDC operation to start. Specifying both values results in an error.
Timestamp Example: --cdc-start-time “2018-03-08T12:12:12”
9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9150 class ModifyReplicationTaskMessage < Struct.new( :replication_task_arn, :replication_task_identifier, :migration_type, :table_mappings, :replication_task_settings, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :task_data) SENSITIVE = [] include Aws::Structure end |
#cdc_stop_position ⇒ String
Indicates when you want a change data capture (CDC) operation to stop. The value can be either server time or commit time.
Server time example: --cdc-stop-position “server_time:2018-02-09T12:12:12”
Commit time example: --cdc-stop-position “commit_time:2018-02-09T12:12:12“
9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9150 class ModifyReplicationTaskMessage < Struct.new( :replication_task_arn, :replication_task_identifier, :migration_type, :table_mappings, :replication_task_settings, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :task_data) SENSITIVE = [] include Aws::Structure end |
#migration_type ⇒ String
The migration type. Valid values: full-load | cdc |
full-load-and-cdc
9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9150 class ModifyReplicationTaskMessage < Struct.new( :replication_task_arn, :replication_task_identifier, :migration_type, :table_mappings, :replication_task_settings, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :task_data) SENSITIVE = [] include Aws::Structure end |
#replication_task_arn ⇒ String
The Amazon Resource Name (ARN) of the replication task.
9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9150 class ModifyReplicationTaskMessage < Struct.new( :replication_task_arn, :replication_task_identifier, :migration_type, :table_mappings, :replication_task_settings, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :task_data) SENSITIVE = [] include Aws::Structure end |
#replication_task_identifier ⇒ String
The replication task identifier.
Constraints:
-
Must contain 1-255 alphanumeric characters or hyphens.
-
First character must be a letter.
-
Cannot end with a hyphen or contain two consecutive hyphens.
9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9150 class ModifyReplicationTaskMessage < Struct.new( :replication_task_arn, :replication_task_identifier, :migration_type, :table_mappings, :replication_task_settings, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :task_data) SENSITIVE = [] include Aws::Structure end |
#replication_task_settings ⇒ String
JSON file that contains settings for the task, such as task metadata settings.
9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9150 class ModifyReplicationTaskMessage < Struct.new( :replication_task_arn, :replication_task_identifier, :migration_type, :table_mappings, :replication_task_settings, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :task_data) SENSITIVE = [] include Aws::Structure end |
#table_mappings ⇒ String
When using the CLI or boto3, provide the path of the JSON file that
contains the table mappings. Precede the path with file://. For
example, --table-mappings file://mappingfile.json. When working
with the DMS API, provide the JSON as the parameter value.
9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9150 class ModifyReplicationTaskMessage < Struct.new( :replication_task_arn, :replication_task_identifier, :migration_type, :table_mappings, :replication_task_settings, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :task_data) SENSITIVE = [] include Aws::Structure end |
#task_data ⇒ String
Supplemental information that the task requires to migrate the data for certain source and target endpoints. For more information, see Specifying Supplemental Data for Task Settings in the Database Migration Service User Guide.
9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9150 class ModifyReplicationTaskMessage < Struct.new( :replication_task_arn, :replication_task_identifier, :migration_type, :table_mappings, :replication_task_settings, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :task_data) SENSITIVE = [] include Aws::Structure end |