Class: Aws::DatabaseMigrationService::Types::MongoDbDataProviderSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::MongoDbDataProviderSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides information that defines a MongoDB data provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_mechanism ⇒ String
The authentication method for connecting to the data provider.
-
#auth_source ⇒ String
The MongoDB database name.
-
#auth_type ⇒ String
The authentication type for the database connection.
-
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate used for SSL connection.
-
#database_name ⇒ String
The database name on the MongoDB data provider.
-
#port ⇒ Integer
The port value for the MongoDB data provider.
-
#server_name ⇒ String
The name of the MongoDB server.
-
#ssl_mode ⇒ String
The SSL mode used to connect to the MongoDB data provider.
Instance Attribute Details
#auth_mechanism ⇒ String
The authentication method for connecting to the data provider. Valid values are DEFAULT, MONGODB_CR, or SCRAM_SHA_1.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9219 class MongoDbDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :auth_type, :auth_source, :auth_mechanism) SENSITIVE = [] include Aws::Structure end |
#auth_source ⇒ String
The MongoDB database name. This setting isn't used when AuthType
is set to "no".
The default is "admin".
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9219 class MongoDbDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :auth_type, :auth_source, :auth_mechanism) SENSITIVE = [] include Aws::Structure end |
#auth_type ⇒ String
The authentication type for the database connection. Valid values are PASSWORD or NO.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9219 class MongoDbDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :auth_type, :auth_source, :auth_mechanism) SENSITIVE = [] include Aws::Structure end |
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate used for SSL connection.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9219 class MongoDbDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :auth_type, :auth_source, :auth_mechanism) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database name on the MongoDB data provider.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9219 class MongoDbDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :auth_type, :auth_source, :auth_mechanism) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port value for the MongoDB data provider.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9219 class MongoDbDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :auth_type, :auth_source, :auth_mechanism) SENSITIVE = [] include Aws::Structure end |
#server_name ⇒ String
The name of the MongoDB server.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9219 class MongoDbDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :auth_type, :auth_source, :auth_mechanism) SENSITIVE = [] include Aws::Structure end |
#ssl_mode ⇒ String
The SSL mode used to connect to the MongoDB data provider. The
default value is none.
9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 9219 class MongoDbDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :certificate_arn, :auth_type, :auth_source, :auth_mechanism) SENSITIVE = [] include Aws::Structure end |