Class: Aws::DatabaseMigrationService::Types::Replication
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::Replication
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides information that describes a serverless replication created
by the CreateReplication operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cdc_start_position ⇒ String
Indicates the start time for a change data capture (CDC) operation.
-
#cdc_start_time ⇒ Time
Indicates the start time for a change data capture (CDC) operation.
-
#cdc_stop_position ⇒ String
Indicates when you want a change data capture (CDC) operation to stop.
-
#failure_messages ⇒ Array<String>
Error and other information about why a serverless replication failed.
-
#is_read_only ⇒ Boolean
Indicates whether the serverless replication is read-only.
-
#premigration_assessment_statuses ⇒ Array<Types::PremigrationAssessmentStatus>
The status output of premigration assessment in describe-replications.
-
#provision_data ⇒ Types::ProvisionData
Information about provisioning resources for an DMS serverless replication.
-
#recovery_checkpoint ⇒ String
Indicates the last checkpoint that occurred during a change data capture (CDC) operation.
-
#replication_config_arn ⇒ String
The Amazon Resource Name for the
ReplicationConfigassociated with the replication. -
#replication_config_identifier ⇒ String
The identifier for the
ReplicationConfigassociated with the replication. -
#replication_create_time ⇒ Time
The time the serverless replication was created.
-
#replication_deprovision_time ⇒ Time
The timestamp when DMS will deprovision the replication.
-
#replication_last_stop_time ⇒ Time
The timestamp when replication was last stopped.
-
#replication_stats ⇒ Types::ReplicationStats
This object provides a collection of statistics about a serverless replication.
-
#replication_type ⇒ String
The type of the serverless replication.
-
#replication_update_time ⇒ Time
The time the serverless replication was updated.
-
#source_endpoint_arn ⇒ String
The Amazon Resource Name for an existing
Endpointthe serverless replication uses for its data source. -
#start_replication_type ⇒ String
The type of replication to start.
-
#status ⇒ String
The current status of the serverless replication.
-
#stop_reason ⇒ String
The reason the replication task was stopped.
-
#target_endpoint_arn ⇒ String
The Amazon Resource Name for an existing
Endpointthe serverless replication uses for its data target.
Instance Attribute Details
#cdc_start_position ⇒ String
Indicates the start time for a change data capture (CDC) operation.
Use either CdcStartTime or CdcStartPosition to specify when you
want a CDC operation to start. Specifying both values results in an
error.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#cdc_start_time ⇒ Time
Indicates the start time for a change data capture (CDC) operation.
Use either CdcStartTime or CdcStartPosition to specify when you
want a CDC operation to start. Specifying both values results in an
error.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#cdc_stop_position ⇒ String
Indicates when you want a change data capture (CDC) operation to stop. The value can be either server time or commit time.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#failure_messages ⇒ Array<String>
Error and other information about why a serverless replication failed.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#is_read_only ⇒ Boolean
Indicates whether the serverless replication is read-only. When set
to true, this replication is managed by DMS as part of a zero-ETL
integration and cannot be modified or deleted directly. You can only
modify or delete read-only replications through their associated
zero-ETL integration.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#premigration_assessment_statuses ⇒ Array<Types::PremigrationAssessmentStatus>
The status output of premigration assessment in describe-replications.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#provision_data ⇒ Types::ProvisionData
Information about provisioning resources for an DMS serverless replication.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#recovery_checkpoint ⇒ String
Indicates the last checkpoint that occurred during a change data
capture (CDC) operation. You can provide this value to the
CdcStartPosition parameter to start a CDC operation that begins at
that checkpoint.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#replication_config_arn ⇒ String
The Amazon Resource Name for the ReplicationConfig associated with
the replication.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#replication_config_identifier ⇒ String
The identifier for the ReplicationConfig associated with the
replication.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#replication_create_time ⇒ Time
The time the serverless replication was created.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#replication_deprovision_time ⇒ Time
The timestamp when DMS will deprovision the replication.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#replication_last_stop_time ⇒ Time
The timestamp when replication was last stopped.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#replication_stats ⇒ Types::ReplicationStats
This object provides a collection of statistics about a serverless replication.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#replication_type ⇒ String
The type of the serverless replication.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#replication_update_time ⇒ Time
The time the serverless replication was updated.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#source_endpoint_arn ⇒ String
The Amazon Resource Name for an existing Endpoint the serverless
replication uses for its data source.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#start_replication_type ⇒ String
The type of replication to start.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the serverless replication.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#stop_reason ⇒ String
The reason the replication task was stopped. This response parameter can return one of the following values:
-
"Stop Reason NORMAL" -
"Stop Reason RECOVERABLE_ERROR" -
"Stop Reason FATAL_ERROR" -
"Stop Reason FULL_LOAD_ONLY_FINISHED" -
"Stop Reason STOPPED_AFTER_FULL_LOAD"– Full load completed, with cached changes not applied -
"Stop Reason STOPPED_AFTER_CACHED_EVENTS"– Full load completed, with cached changes applied -
"Stop Reason EXPRESS_LICENSE_LIMITS_REACHED" -
"Stop Reason STOPPED_AFTER_DDL_APPLY"– User-defined stop task after DDL applied -
"Stop Reason STOPPED_DUE_TO_LOW_MEMORY" -
"Stop Reason STOPPED_DUE_TO_LOW_DISK" -
"Stop Reason STOPPED_AT_SERVER_TIME"– User-defined server time for stopping task -
"Stop Reason STOPPED_AT_COMMIT_TIME"– User-defined commit time for stopping task -
"Stop Reason RECONFIGURATION_RESTART" -
"Stop Reason RECYCLE_TASK"
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |
#target_endpoint_arn ⇒ String
The Amazon Resource Name for an existing Endpoint the serverless
replication uses for its data target.
11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11937 class Replication < Struct.new( :replication_config_identifier, :replication_config_arn, :source_endpoint_arn, :target_endpoint_arn, :replication_type, :status, :provision_data, :premigration_assessment_statuses, :stop_reason, :failure_messages, :replication_stats, :start_replication_type, :cdc_start_time, :cdc_start_position, :cdc_stop_position, :recovery_checkpoint, :replication_create_time, :replication_update_time, :replication_last_stop_time, :replication_deprovision_time, :is_read_only) SENSITIVE = [] include Aws::Structure end |