Class: Aws::DatabaseMigrationService::Types::StartMetadataModelConversionMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::StartMetadataModelConversionMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
-
#selection_rules ⇒ String
A JSON string that identifies the metadata models to convert.
Instance Attribute Details
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
14218 14219 14220 14221 14222 14223 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14218 class StartMetadataModelConversionMessage < Struct.new( :migration_project_identifier, :selection_rules) SENSITIVE = [] include Aws::Structure end |
#selection_rules ⇒ String
A JSON string that identifies the metadata models to convert. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.
Usage:
-
Accepts only source selection rules, where
server-namein the object locator matches the source data provider. -
Supports
explicit,include, andexcluderule actions.
14218 14219 14220 14221 14222 14223 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14218 class StartMetadataModelConversionMessage < Struct.new( :migration_project_identifier, :selection_rules) SENSITIVE = [] include Aws::Structure end |