Class: Aws::DatabaseMigrationService::Types::StartMetadataModelCreationMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metadata_model_nameString

The name for the metadata model to use in subsequent operations.

Returns:

  • (String)


14270
14271
14272
14273
14274
14275
14276
14277
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14270

class StartMetadataModelCreationMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules,
  :metadata_model_name,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#migration_project_identifierString

The migration project name or Amazon Resource Name (ARN).

Returns:

  • (String)


14270
14271
14272
14273
14274
14275
14276
14277
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14270

class StartMetadataModelCreationMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules,
  :metadata_model_name,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesTypes::MetadataModelProperties

The properties of the metadata model.



14270
14271
14272
14273
14274
14275
14276
14277
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14270

class StartMetadataModelCreationMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules,
  :metadata_model_name,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#selection_rulesString

A JSON string that identifies the source schema for the metadata model. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.

Usage:

  • Accepts only source selection rules, where server-name in the object locator matches the source data provider.

  • Supports only explicit rule actions.

  • Exactly one rule is allowed.

Returns:

  • (String)


14270
14271
14272
14273
14274
14275
14276
14277
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14270

class StartMetadataModelCreationMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules,
  :metadata_model_name,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end