Class: Aws::DatabaseMigrationService::Types::StartMetadataModelExportToTargetMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#migration_project_identifierString

The migration project name or Amazon Resource Name (ARN).

Returns:

  • (String)


14374
14375
14376
14377
14378
14379
14380
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14374

class StartMetadataModelExportToTargetMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules,
  :overwrite_extension_pack)
  SENSITIVE = []
  include Aws::Structure
end

#overwrite_extension_packBoolean

Specifies whether to overwrite the extension pack if one already exists on the target database. The default value is true.

Returns:

  • (Boolean)


14374
14375
14376
14377
14378
14379
14380
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14374

class StartMetadataModelExportToTargetMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules,
  :overwrite_extension_pack)
  SENSITIVE = []
  include Aws::Structure
end

#selection_rulesString

A JSON string that identifies the metadata models to export to the target database. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.

Usage:

  • Accepts only target selection rules, where server-name in the object locator matches the target data provider.

  • Supports explicit, include, and exclude rule actions.

Returns:

  • (String)


14374
14375
14376
14377
14378
14379
14380
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14374

class StartMetadataModelExportToTargetMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules,
  :overwrite_extension_pack)
  SENSITIVE = []
  include Aws::Structure
end