Class: Aws::DatabaseMigrationService::Types::StartMetadataModelImportMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#migration_project_identifierString

The migration project name or Amazon Resource Name (ARN).

Returns:

  • (String)


14437
14438
14439
14440
14441
14442
14443
14444
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14437

class StartMetadataModelImportMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules,
  :origin,
  :refresh)
  SENSITIVE = []
  include Aws::Structure
end

#originString

Specifies the metadata tree to import into.

You cannot import from a virtual target data provider.

Returns:

  • (String)


14437
14438
14439
14440
14441
14442
14443
14444
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14437

class StartMetadataModelImportMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules,
  :origin,
  :refresh)
  SENSITIVE = []
  include Aws::Structure
end

#refreshBoolean

Specifies whether to refresh the selected metadata models from the data provider.

When true, the import reloads the selected metadata models with current definitions and removes their existing subtree.

When false (default), the import loads the full subtree that has not yet been loaded into the metadata tree.

Returns:

  • (Boolean)


14437
14438
14439
14440
14441
14442
14443
14444
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14437

class StartMetadataModelImportMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules,
  :origin,
  :refresh)
  SENSITIVE = []
  include Aws::Structure
end

#selection_rulesString

A JSON string that identifies the metadata models to import from the data provider. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.

Usage:

  • Accepts source or target selection rules depending on the Origin parameter. The server-name in the object locator must match the corresponding data provider.

  • Supports explicit, include, and exclude rule actions.

Returns:

  • (String)


14437
14438
14439
14440
14441
14442
14443
14444
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14437

class StartMetadataModelImportMessage < Struct.new(
  :migration_project_identifier,
  :selection_rules,
  :origin,
  :refresh)
  SENSITIVE = []
  include Aws::Structure
end