Class: Aws::DatabaseMigrationService::Types::StartRecommendationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::StartRecommendationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#database_id ⇒ String
The identifier of the source database to analyze and provide recommendations for.
-
#settings ⇒ Types::RecommendationSettings
The settings in JSON format that Fleet Advisor uses to determine target engine recommendations.
Instance Attribute Details
#database_id ⇒ String
The identifier of the source database to analyze and provide recommendations for.
14476 14477 14478 14479 14480 14481 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14476 class StartRecommendationsRequest < Struct.new( :database_id, :settings) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Types::RecommendationSettings
The settings in JSON format that Fleet Advisor uses to determine target engine recommendations. These parameters include target instance sizing and availability and durability settings. For target instance sizing, Fleet Advisor supports the following two options: total capacity and resource utilization. For availability and durability, Fleet Advisor supports the following two options: production (Multi-AZ deployments) and Dev/Test (Single-AZ deployments).
14476 14477 14478 14479 14480 14481 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14476 class StartRecommendationsRequest < Struct.new( :database_id, :settings) SENSITIVE = [] include Aws::Structure end |