Class: Aws::DatabaseMigrationService::Types::StartReplicationTaskMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cdc_start_positionString

Indicates when you want a change data capture (CDC) operation to start. Use either CdcStartPosition or CdcStartTime to specify when you want a CDC operation to start. Specifying both values results in an error.

The value can be in date, checkpoint, or LSN/SCN format.

Date Example: –cdc-start-position “2018-03-08T12:12:12”

Checkpoint Example: –cdc-start-position “checkpoint:V1#27#mysql-bin-changelog.157832:1975:-1:2002:677883278264080:mysql-bin-changelog.157832:1876#0#0#*#0#93”

LSN Example: –cdc-start-position “mysql-bin-changelog.000024:373”

<note markdown=“1”> When you use this task setting with a source PostgreSQL database, a logical replication slot should already be created and associated with the source endpoint. You can verify this by setting the ‘slotName` extra connection attribute to the name of this logical replication slot. For more information, see [Extra Connection Attributes When Using PostgreSQL as a Source for DMS].

</note>

[1]: docs.aws.amazon.com/dms/latest/userguide/CHAP_Source.PostgreSQL.html#CHAP_Source.PostgreSQL.ConnectionAttrib

Returns:

  • (String)


14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14495

class StartReplicationTaskMessage < Struct.new(
  :replication_task_arn,
  :start_replication_task_type,
  :cdc_start_time,
  :cdc_start_position,
  :cdc_stop_position)
  SENSITIVE = []
  include Aws::Structure
end

#cdc_start_timeTime

Indicates the start time for a change data capture (CDC) operation. Use either CdcStartTime or CdcStartPosition to specify when you want a CDC operation to start. Specifying both values results in an error.

Timestamp Example: –cdc-start-time “2018-03-08T12:12:12”

Returns:

  • (Time)


14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14495

class StartReplicationTaskMessage < Struct.new(
  :replication_task_arn,
  :start_replication_task_type,
  :cdc_start_time,
  :cdc_start_position,
  :cdc_stop_position)
  SENSITIVE = []
  include Aws::Structure
end

#cdc_stop_positionString

Indicates when you want a change data capture (CDC) operation to stop. The value can be either server time or commit time.

Server time example: –cdc-stop-position “server_time:2018-02-09T12:12:12”

Commit time example: –cdc-stop-position “commit_time:2018-02-09T12:12:12“

Returns:

  • (String)


14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14495

class StartReplicationTaskMessage < Struct.new(
  :replication_task_arn,
  :start_replication_task_type,
  :cdc_start_time,
  :cdc_start_position,
  :cdc_stop_position)
  SENSITIVE = []
  include Aws::Structure
end

#replication_task_arnString

The Amazon Resource Name (ARN) of the replication task to be started.

Returns:

  • (String)


14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14495

class StartReplicationTaskMessage < Struct.new(
  :replication_task_arn,
  :start_replication_task_type,
  :cdc_start_time,
  :cdc_start_position,
  :cdc_stop_position)
  SENSITIVE = []
  include Aws::Structure
end

#start_replication_task_typeString

The type of replication task to start.

‘start-replication` is the only valid action that can be used for the first time a task with the migration type of `full-load`full-load, `full-load-and-cdc` or `cdc` is run. Any other action used for the first time on a given task, such as `resume-processing` and reload-target will result in data errors.

You can also use ReloadTables to reload specific tables that failed during migration instead of restarting the task.

For a ‘full-load` task, the resume-processing option will reload any tables that were partially loaded or not yet loaded during the full load phase.

For a ‘full-load-and-cdc` task, DMS migrates table data, and then applies data changes that occur on the source. To load all the tables again, and start capturing source changes, use `reload-target`. Otherwise use `resume-processing`, to replicate the changes from the last stop position.

For a ‘cdc` only task, to start from a specific position, you must use start-replication and also specify the start position. Check the source endpoint DMS documentation for any limitations. For example, not all sources support starting from a time.

<note markdown=“1”> ‘resume-processing` is only available for previously executed tasks.

</note>

Returns:

  • (String)


14495
14496
14497
14498
14499
14500
14501
14502
14503
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14495

class StartReplicationTaskMessage < Struct.new(
  :replication_task_arn,
  :start_replication_task_type,
  :cdc_start_time,
  :cdc_start_position,
  :cdc_stop_position)
  SENSITIVE = []
  include Aws::Structure
end