Class: Aws::DatabaseMigrationService::Types::SupportedEndpointType
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::SupportedEndpointType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides information about types of supported endpoints in response to a request by the DescribeEndpointTypes operation. This information includes the type of endpoint, the database engine name, and whether change data capture (CDC) is supported.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint_type ⇒ String
The type of endpoint.
-
#engine_display_name ⇒ String
The expanded name for the engine name.
-
#engine_name ⇒ String
The database engine name.
-
#replication_instance_engine_minimum_version ⇒ String
The earliest DMS engine version that supports this endpoint engine.
-
#supports_cdc ⇒ Boolean
Indicates if change data capture (CDC) is supported.
Instance Attribute Details
#endpoint_type ⇒ String
The type of endpoint. Valid values are source and target.
13977 13978 13979 13980 13981 13982 13983 13984 13985 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13977 class SupportedEndpointType < Struct.new( :engine_name, :supports_cdc, :endpoint_type, :replication_instance_engine_minimum_version, :engine_display_name) SENSITIVE = [] include Aws::Structure end |
#engine_display_name ⇒ String
The expanded name for the engine name. For example, if the EngineName parameter is “aurora”, this value would be “Amazon Aurora MySQL”.
13977 13978 13979 13980 13981 13982 13983 13984 13985 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13977 class SupportedEndpointType < Struct.new( :engine_name, :supports_cdc, :endpoint_type, :replication_instance_engine_minimum_version, :engine_display_name) SENSITIVE = [] include Aws::Structure end |
#engine_name ⇒ String
The database engine name. Valid values, depending on the EndpointType, include ‘“mysql”`, `“oracle”`, `“postgres”`, `“mariadb”`, `“aurora”`, `“aurora-postgresql”`, `“redshift”`, `“s3”`, `“db2”`, `“db2-zos”`, `“azuredb”`, `“sybase”`, `“dynamodb”`, `“mongodb”`, `“kinesis”`, `“kafka”`, `“elasticsearch”`, `“documentdb”`, `“sqlserver”`, `“neptune”`, and `“babelfish”`.
13977 13978 13979 13980 13981 13982 13983 13984 13985 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13977 class SupportedEndpointType < Struct.new( :engine_name, :supports_cdc, :endpoint_type, :replication_instance_engine_minimum_version, :engine_display_name) SENSITIVE = [] include Aws::Structure end |
#replication_instance_engine_minimum_version ⇒ String
The earliest DMS engine version that supports this endpoint engine. Note that endpoint engines released with DMS versions earlier than 3.1.1 do not return a value for this parameter.
13977 13978 13979 13980 13981 13982 13983 13984 13985 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13977 class SupportedEndpointType < Struct.new( :engine_name, :supports_cdc, :endpoint_type, :replication_instance_engine_minimum_version, :engine_display_name) SENSITIVE = [] include Aws::Structure end |
#supports_cdc ⇒ Boolean
Indicates if change data capture (CDC) is supported.
13977 13978 13979 13980 13981 13982 13983 13984 13985 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13977 class SupportedEndpointType < Struct.new( :engine_name, :supports_cdc, :endpoint_type, :replication_instance_engine_minimum_version, :engine_display_name) SENSITIVE = [] include Aws::Structure end |