Class: Aws::DatabaseMigrationService::Types::SybaseAseDataProviderSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::SybaseAseDataProviderSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides information that defines an SAP ASE data provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate used for SSL connection.
-
#database_name ⇒ String
The database name on the SAP ASE data provider.
-
#encrypt_password ⇒ Boolean
Specifies whether to encrypt the password when connecting to the Sybase ASE database.
-
#port ⇒ Integer
The port value for the SAP ASE data provider.
-
#server_name ⇒ String
The name of the SAP ASE server.
-
#ssl_mode ⇒ String
The SSL mode used to connect to the SAP ASE data provider.
Instance Attribute Details
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate used for SSL connection.
15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15072 class SybaseAseDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :encrypt_password, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database name on the SAP ASE data provider.
15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15072 class SybaseAseDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :encrypt_password, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#encrypt_password ⇒ Boolean
Specifies whether to encrypt the password when connecting to the Sybase ASE database. When set to true, the connection password is encrypted during transmission. Default is true.
15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15072 class SybaseAseDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :encrypt_password, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port value for the SAP ASE data provider.
15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15072 class SybaseAseDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :encrypt_password, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#server_name ⇒ String
The name of the SAP ASE server.
15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15072 class SybaseAseDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :encrypt_password, :certificate_arn) SENSITIVE = [] include Aws::Structure end |
#ssl_mode ⇒ String
The SSL mode used to connect to the SAP ASE data provider. The
default value is none.
15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15072 class SybaseAseDataProviderSettings < Struct.new( :server_name, :port, :database_name, :ssl_mode, :encrypt_password, :certificate_arn) SENSITIVE = [] include Aws::Structure end |