Class: Aws::DatabaseMigrationService::Types::SybaseSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::SybaseSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides information that defines a SAP ASE endpoint.
Constant Summary collapse
- SENSITIVE =
[:password]
Instance Attribute Summary collapse
-
#database_name ⇒ String
Database name for the endpoint.
-
#password ⇒ String
Endpoint connection password.
-
#port ⇒ Integer
Endpoint TCP port.
-
#secrets_manager_access_role_arn ⇒ String
The full Amazon Resource Name (ARN) of the IAM role that specifies DMS as the trusted entity and grants the required permissions to access the value in
SecretsManagerSecret. -
#secrets_manager_secret_id ⇒ String
The full ARN, partial ARN, or friendly name of the
SecretsManagerSecretthat contains the SAP SAE endpoint connection details. -
#server_name ⇒ String
Fully qualified domain name of the endpoint.
-
#username ⇒ String
Endpoint connection user name.
Instance Attribute Details
#database_name ⇒ String
Database name for the endpoint.
14042 14043 14044 14045 14046 14047 14048 14049 14050 14051 14052 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14042 class SybaseSettings < Struct.new( :database_name, :password, :port, :server_name, :username, :secrets_manager_access_role_arn, :secrets_manager_secret_id) SENSITIVE = [:password] include Aws::Structure end |
#password ⇒ String
Endpoint connection password.
14042 14043 14044 14045 14046 14047 14048 14049 14050 14051 14052 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14042 class SybaseSettings < Struct.new( :database_name, :password, :port, :server_name, :username, :secrets_manager_access_role_arn, :secrets_manager_secret_id) SENSITIVE = [:password] include Aws::Structure end |
#port ⇒ Integer
Endpoint TCP port. The default is 5000.
14042 14043 14044 14045 14046 14047 14048 14049 14050 14051 14052 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14042 class SybaseSettings < Struct.new( :database_name, :password, :port, :server_name, :username, :secrets_manager_access_role_arn, :secrets_manager_secret_id) SENSITIVE = [:password] include Aws::Structure end |
#secrets_manager_access_role_arn ⇒ String
The full Amazon Resource Name (ARN) of the IAM role that specifies DMS as the trusted entity and grants the required permissions to access the value in SecretsManagerSecret. The role must allow the iam:PassRole action. SecretsManagerSecret has the value of the Amazon Web Services Secrets Manager secret that allows access to the SAP ASE endpoint.
<note markdown=“1”> You can specify one of two sets of values for these permissions. You can specify the values for this setting and SecretsManagerSecretId. Or you can specify clear-text values for UserName, Password, ServerName, and Port. You can’t specify both. For more information on creating this SecretsManagerSecret and the SecretsManagerAccessRoleArn and SecretsManagerSecretId required to access it, see [Using secrets to access Database Migration Service resources] in the *Database Migration Service User Guide*.
</note>
[1]: docs.aws.amazon.com/dms/latest/userguide/CHAP_Security.html#security-iam-secretsmanager
14042 14043 14044 14045 14046 14047 14048 14049 14050 14051 14052 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14042 class SybaseSettings < Struct.new( :database_name, :password, :port, :server_name, :username, :secrets_manager_access_role_arn, :secrets_manager_secret_id) SENSITIVE = [:password] include Aws::Structure end |
#secrets_manager_secret_id ⇒ String
The full ARN, partial ARN, or friendly name of the SecretsManagerSecret that contains the SAP SAE endpoint connection details.
14042 14043 14044 14045 14046 14047 14048 14049 14050 14051 14052 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14042 class SybaseSettings < Struct.new( :database_name, :password, :port, :server_name, :username, :secrets_manager_access_role_arn, :secrets_manager_secret_id) SENSITIVE = [:password] include Aws::Structure end |
#server_name ⇒ String
Fully qualified domain name of the endpoint.
14042 14043 14044 14045 14046 14047 14048 14049 14050 14051 14052 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14042 class SybaseSettings < Struct.new( :database_name, :password, :port, :server_name, :username, :secrets_manager_access_role_arn, :secrets_manager_secret_id) SENSITIVE = [:password] include Aws::Structure end |
#username ⇒ String
Endpoint connection user name.
14042 14043 14044 14045 14046 14047 14048 14049 14050 14051 14052 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14042 class SybaseSettings < Struct.new( :database_name, :password, :port, :server_name, :username, :secrets_manager_access_role_arn, :secrets_manager_secret_id) SENSITIVE = [:password] include Aws::Structure end |