Class: Aws::DatabaseMigrationService::Types::TableStatistics
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::TableStatistics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides a collection of table statistics in response to a request by
the DescribeTableStatistics operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#applied_ddls ⇒ Integer
The number of data definition language (DDL) statements used to build and modify the structure of your tables applied on the target.
-
#applied_deletes ⇒ Integer
The number of delete actions applied on a target table.
-
#applied_inserts ⇒ Integer
The number of insert actions applied on a target table.
-
#applied_updates ⇒ Integer
The number of update actions applied on a target table.
-
#ddls ⇒ Integer
The data definition language (DDL) used to build and modify the structure of your tables.
-
#deletes ⇒ Integer
The number of delete actions performed on a table.
-
#full_load_condtnl_chk_failed_rows ⇒ Integer
The number of rows that failed conditional checks during the full load operation (valid only for migrations where DynamoDB is the target).
-
#full_load_end_time ⇒ Time
The time when the full load operation completed.
-
#full_load_error_rows ⇒ Integer
The number of rows that failed to load during the full load operation (valid only for migrations where DynamoDB is the target).
-
#full_load_reloaded ⇒ Boolean
A value that indicates if the table was reloaded (
true) or loaded as part of a new full load operation (false). -
#full_load_rows ⇒ Integer
The number of rows added during the full load operation.
-
#full_load_start_time ⇒ Time
The time when the full load operation started.
-
#inserts ⇒ Integer
The number of insert actions performed on a table.
-
#last_update_time ⇒ Time
The last time a table was updated.
-
#resync_progress ⇒ Float
Calculates the percentage of failed validations that were successfully resynced to the system.
-
#resync_rows_attempted ⇒ Integer
Records the total number of mismatched data rows where the system attempted to apply fixes in the target database.
-
#resync_rows_failed ⇒ Integer
Records the total number of mismatched data rows where fix attempts failed in the target database.
-
#resync_rows_succeeded ⇒ Integer
Records the total number of mismatched data rows where fixes were successfully applied in the target database.
-
#resync_state ⇒ String
Records the current state of table resynchronization in the migration task.
-
#schema_name ⇒ String
The schema name.
-
#table_name ⇒ String
The name of the table.
-
#table_state ⇒ String
The state of the tables described.
-
#updates ⇒ Integer
The number of update actions performed on a table.
-
#validation_failed_records ⇒ Integer
The number of records that failed validation.
-
#validation_pending_records ⇒ Integer
The number of records that have yet to be validated.
-
#validation_state ⇒ String
The validation state of the table.
-
#validation_state_details ⇒ String
Additional details about the state of validation.
-
#validation_suspended_records ⇒ Integer
The number of records that couldn't be validated.
Instance Attribute Details
#applied_ddls ⇒ Integer
The number of data definition language (DDL) statements used to build and modify the structure of your tables applied on the target.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#applied_deletes ⇒ Integer
The number of delete actions applied on a target table.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#applied_inserts ⇒ Integer
The number of insert actions applied on a target table.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#applied_updates ⇒ Integer
The number of update actions applied on a target table.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#ddls ⇒ Integer
The data definition language (DDL) used to build and modify the structure of your tables.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#deletes ⇒ Integer
The number of delete actions performed on a table.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#full_load_condtnl_chk_failed_rows ⇒ Integer
The number of rows that failed conditional checks during the full load operation (valid only for migrations where DynamoDB is the target).
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#full_load_end_time ⇒ Time
The time when the full load operation completed.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#full_load_error_rows ⇒ Integer
The number of rows that failed to load during the full load operation (valid only for migrations where DynamoDB is the target).
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#full_load_reloaded ⇒ Boolean
A value that indicates if the table was reloaded (true) or loaded
as part of a new full load operation (false).
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#full_load_rows ⇒ Integer
The number of rows added during the full load operation.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#full_load_start_time ⇒ Time
The time when the full load operation started.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#inserts ⇒ Integer
The number of insert actions performed on a table.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#last_update_time ⇒ Time
The last time a table was updated.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#resync_progress ⇒ Float
Calculates the percentage of failed validations that were successfully resynced to the system.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#resync_rows_attempted ⇒ Integer
Records the total number of mismatched data rows where the system attempted to apply fixes in the target database.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#resync_rows_failed ⇒ Integer
Records the total number of mismatched data rows where fix attempts failed in the target database.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#resync_rows_succeeded ⇒ Integer
Records the total number of mismatched data rows where fixes were successfully applied in the target database.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#resync_state ⇒ String
Records the current state of table resynchronization in the migration task.
This parameter can have the following values:
-
Not enabled – Resync is not enabled for the table in the migration task.
-
Pending – The tables are waiting for resync.
-
In progress – Resync in progress for some records in the table.
-
No primary key – The table could not be resynced because it has no primary key.
-
Last resync at:
date/time– Resync session is finished at time. Time provided in UTC format.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#schema_name ⇒ String
The schema name.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#table_state ⇒ String
The state of the tables described.
Valid states: Table does not exist | Before load | Full load | Table completed | Table cancelled | Table error | Table is being reloaded
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#updates ⇒ Integer
The number of update actions performed on a table.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#validation_failed_records ⇒ Integer
The number of records that failed validation.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#validation_pending_records ⇒ Integer
The number of records that have yet to be validated.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#validation_state ⇒ String
The validation state of the table.
This parameter can have the following values:
-
Not enabled – Validation isn't enabled for the table in the migration task.
-
Pending records – Some records in the table are waiting for validation.
-
Mismatched records – Some records in the table don't match between the source and target.
-
Suspended records – Some records in the table couldn't be validated.
-
No primary key –The table couldn't be validated because it has no primary key.
-
Table error – The table wasn't validated because it's in an error state and some data wasn't migrated.
-
Validated – All rows in the table are validated. If the table is updated, the status can change from Validated.
-
Error – The table couldn't be validated because of an unexpected error.
-
Pending validation – The table is waiting validation.
-
Preparing table – Preparing the table enabled in the migration task for validation.
-
Pending revalidation – All rows in the table are pending validation after the table was updated.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#validation_state_details ⇒ String
Additional details about the state of validation.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |
#validation_suspended_records ⇒ Integer
The number of records that couldn't be validated.
15331 15332 15333 15334 15335 15336 15337 15338 15339 15340 15341 15342 15343 15344 15345 15346 15347 15348 15349 15350 15351 15352 15353 15354 15355 15356 15357 15358 15359 15360 15361 15362 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15331 class TableStatistics < Struct.new( :schema_name, :table_name, :inserts, :deletes, :updates, :ddls, :applied_inserts, :applied_deletes, :applied_updates, :applied_ddls, :full_load_rows, :full_load_condtnl_chk_failed_rows, :full_load_error_rows, :full_load_start_time, :full_load_end_time, :full_load_reloaded, :last_update_time, :table_state, :validation_pending_records, :validation_failed_records, :validation_suspended_records, :validation_state, :validation_state_details, :resync_state, :resync_rows_attempted, :resync_rows_succeeded, :resync_rows_failed, :resync_progress) SENSITIVE = [] include Aws::Structure end |