Class: Aws::DatabaseMigrationService::Types::TimestreamSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::TimestreamSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides information that defines an Amazon Timestream endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cdc_inserts_and_updates ⇒ Boolean
Set this attribute to
trueto specify that DMS only applies inserts and updates, and not deletes. -
#database_name ⇒ String
Database name for the endpoint.
-
#enable_magnetic_store_writes ⇒ Boolean
Set this attribute to
trueto enable memory store writes. -
#magnetic_duration ⇒ Integer
Set this attribute to specify the default magnetic duration applied to the Amazon Timestream tables in days.
-
#memory_duration ⇒ Integer
Set this attribute to specify the length of time to store all of the tables in memory that are migrated into Amazon Timestream from the source database.
Instance Attribute Details
#cdc_inserts_and_updates ⇒ Boolean
Set this attribute to true to specify that DMS only applies inserts and updates, and not deletes. Amazon Timestream does not allow deleting records, so if this value is false, DMS nulls out the corresponding record in the Timestream database rather than deleting it.
14382 14383 14384 14385 14386 14387 14388 14389 14390 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14382 class TimestreamSettings < Struct.new( :database_name, :memory_duration, :magnetic_duration, :cdc_inserts_and_updates, :enable_magnetic_store_writes) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
Database name for the endpoint.
14382 14383 14384 14385 14386 14387 14388 14389 14390 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14382 class TimestreamSettings < Struct.new( :database_name, :memory_duration, :magnetic_duration, :cdc_inserts_and_updates, :enable_magnetic_store_writes) SENSITIVE = [] include Aws::Structure end |
#enable_magnetic_store_writes ⇒ Boolean
Set this attribute to true to enable memory store writes. When this value is false, DMS does not write records that are older in days than the value specified in MagneticDuration, because Amazon Timestream does not allow memory writes by default. For more information, see [Storage] in the [Amazon Timestream Developer Guide].
[1]: docs.aws.amazon.com/timestream/latest/developerguide/storage.html [2]: docs.aws.amazon.com/timestream/latest/developerguide/
14382 14383 14384 14385 14386 14387 14388 14389 14390 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14382 class TimestreamSettings < Struct.new( :database_name, :memory_duration, :magnetic_duration, :cdc_inserts_and_updates, :enable_magnetic_store_writes) SENSITIVE = [] include Aws::Structure end |
#magnetic_duration ⇒ Integer
Set this attribute to specify the default magnetic duration applied to the Amazon Timestream tables in days. This is the number of days that records remain in magnetic store before being discarded. For more information, see [Storage] in the [Amazon Timestream Developer Guide].
[1]: docs.aws.amazon.com/timestream/latest/developerguide/storage.html [2]: docs.aws.amazon.com/timestream/latest/developerguide/
14382 14383 14384 14385 14386 14387 14388 14389 14390 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14382 class TimestreamSettings < Struct.new( :database_name, :memory_duration, :magnetic_duration, :cdc_inserts_and_updates, :enable_magnetic_store_writes) SENSITIVE = [] include Aws::Structure end |
#memory_duration ⇒ Integer
Set this attribute to specify the length of time to store all of the tables in memory that are migrated into Amazon Timestream from the source database. Time is measured in units of hours. When Timestream data comes in, it first resides in memory for the specified duration, which allows quick access to it.
14382 14383 14384 14385 14386 14387 14388 14389 14390 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14382 class TimestreamSettings < Struct.new( :database_name, :memory_duration, :magnetic_duration, :cdc_inserts_and_updates, :enable_magnetic_store_writes) SENSITIVE = [] include Aws::Structure end |