Class: Aws::DatabaseMigrationService::Types::UpdateSubscriptionsToEventBridgeMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::UpdateSubscriptionsToEventBridgeMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#force_move ⇒ Boolean
When set to true, this operation migrates DMS subscriptions for Amazon SNS notifications no matter what your replication instance version is.
Instance Attribute Details
#force_move ⇒ Boolean
When set to true, this operation migrates DMS subscriptions for Amazon SNS notifications no matter what your replication instance version is. If not set or set to false, this operation runs only when all your replication instances are from DMS version 3.4.5 or higher.
15543 15544 15545 15546 15547 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 15543 class UpdateSubscriptionsToEventBridgeMessage < Struct.new( :force_move) SENSITIVE = [] include Aws::Structure end |