Class: Aws::DatabaseMigrationService::Waiters::EndpointDeleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb,
sig/waiters.rbs

Overview

Wait until testing endpoint is deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ EndpointDeleted

Returns a new instance of EndpointDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 5
  • :before_attempt (Proc)
  • :before_wait (Proc)


101
102
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 101

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



138
139
140
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 138

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeEndpointsResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    Filters applied to the endpoints.

    Valid filter names: endpoint-arn | endpoint-type | endpoint-id | engine-name

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: Minimum 20, maximum 100.

  • :marker (String)

    An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:



133
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 133

def wait: (