Class: Aws::DatabaseMigrationService::Waiters::ExtensionPackAssociated

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb,
sig/waiters.rbs

Overview

Wait until DMS extension pack is associated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ExtensionPackAssociated

Returns a new instance of ExtensionPackAssociated.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


151
152
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 151

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



183
184
185
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 183

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeExtensionPackAssociationsResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :migration_project_identifier (required, String)

    The name or Amazon Resource Name (ARN) for the migration project.

  • :filters (Array<Types::Filter>)

    Filters applied to the extension pack associations described in the form of key-value pairs.

  • :marker (String)

    Specifies the unique pagination token that makes it possible to display the next page of results. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

    If Marker is returned by a previous response, there are more results available. The value of Marker is a unique pagination token for each page. To retrieve the next page, make the call again using the returned token and keeping all other arguments unchanged.

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, DMS includes a pagination token in the response so that you can retrieve the remaining results.

Returns:



178
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 178

def wait: (