Class: Aws::DatabaseMigrationService::Waiters::MetadataModelCreationCancelled

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb,
sig/waiters.rbs

Overview

Wait until DMS metadata model creation is cancelled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ MetadataModelCreationCancelled

Returns a new instance of MetadataModelCreationCancelled.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 180
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


376
377
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 376

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



408
409
410
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 408

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeMetadataModelCreationsResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    The filters to apply to the metadata model creation requests.

    The following filter names are supported:

    • request-id – The request identifier.

    • status – The request status. Valid values: RECEIVED, IN_PROGRESS, SUCCESS, FAILED, CANCELING, CANCELED.

  • :marker (String)

    Specifies the unique pagination token that makes it possible to display the next page of results. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

    If Marker is returned by a previous response, there are more results available. The value of Marker is a unique pagination token for each page. To retrieve the next page, make the call again using the returned token and keeping all other arguments unchanged.

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, DMS includes a pagination token in the response so that you can retrieve the remaining results.

  • :migration_project_identifier (required, String)

    The migration project name or Amazon Resource Name (ARN).

Returns:



403
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 403

def wait: (