Class: Aws::DatabaseMigrationService::Waiters::MetadataModelExportedAsScript

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb

Overview

Wait until DMS metadata model is exported as script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ MetadataModelExportedAsScript

Returns a new instance of MetadataModelExportedAsScript.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 90
  • :delay (Integer) — default: 20
  • :before_attempt (Proc)
  • :before_wait (Proc)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 421

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 90,
    delay: 20,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_metadata_model_exports_as_script,
      acceptors: [
        {
          "argument" => "requests[].status",
          "expected" => "SUCCESS",
          "matcher" => "pathAll",
          "state" => "success"
        },
        {
          "argument" => "requests[].status",
          "expected" => "FAILED",
          "matcher" => "pathAny",
          "state" => "failure"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



453
454
455
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 453

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeMetadataModelExportsAsScriptResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :migration_project_identifier (required, String)

    The migration project name or Amazon Resource Name (ARN).

  • :filters (Array<Types::Filter>)

    Filters applied to the metadata model exports described in the form of key-value pairs.

  • :marker (String)

    Specifies the unique pagination token that makes it possible to display the next page of results. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.

    If ‘Marker` is returned by a previous response, there are more results available. The value of `Marker` is a unique pagination token for each page. To retrieve the next page, make the call again using the returned token and keeping all other arguments unchanged.

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, DMS includes a pagination token in the response so that you can retrieve the remaining results.

Returns:



448
449
450
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 448

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end