Class: Aws::DatabaseMigrationService::Waiters::MetadataModelImported

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb

Overview

Wait until DMS metadata model is imported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ MetadataModelImported

Returns a new instance of MetadataModelImported.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 30
  • :delay (Integer) — default: 60
  • :before_attempt (Proc)
  • :before_wait (Proc)


511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 511

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 30,
    delay: 60,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_metadata_model_imports,
      acceptors: [
        {
          "argument" => "requests[].status",
          "expected" => "SUCCESS",
          "matcher" => "pathAll",
          "state" => "success"
        },
        {
          "argument" => "requests[].status",
          "expected" => "FAILED",
          "matcher" => "pathAny",
          "state" => "failure"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



543
544
545
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 543

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeMetadataModelImportsResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :migration_project_identifier (required, String)

    The migration project name or Amazon Resource Name (ARN).

  • :filters (Array<Types::Filter>)

    Filters applied to the metadata model imports described in the form of key-value pairs.

  • :marker (String)

    Specifies the unique pagination token that makes it possible to display the next page of results. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.

    If ‘Marker` is returned by a previous response, there are more results available. The value of `Marker` is a unique pagination token for each page. To retrieve the next page, make the call again using the returned token and keeping all other arguments unchanged.

  • :max_records (Integer)

    A paginated list of metadata model imports.

Returns:



538
539
540
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 538

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end