Class: Aws::DatabaseMigrationService::Waiters::ReplicationTaskDeleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb,
sig/waiters.rbs

Overview

Wait until DMS replication task is deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ReplicationTaskDeleted

Returns a new instance of ReplicationTaskDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


663
664
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 663

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



718
719
720
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 718

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeReplicationTasksResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    Filters applied to replication tasks.

    Valid filter names: replication-task-arn | replication-task-id | migration-type | endpoint-arn | replication-instance-arn

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: Minimum 20, maximum 100.

  • :marker (String)

    An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  • :without_settings (Boolean)

    An option to set to avoid returning information about settings. Use this to reduce overhead when setting information is too large. To use this option, choose true; otherwise, choose false (the default).

Returns:



713
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 713

def wait: (