Class: Aws::DatabaseMigrationService::Waiters::ReplicationTaskReady

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb

Overview

Wait until DMS replication task is ready.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ReplicationTaskReady

Returns a new instance of ReplicationTaskReady.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 731

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 60,
    delay: 15,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_replication_tasks,
      acceptors: [
        {
          "argument" => "replication_tasks[].status",
          "expected" => "ready",
          "matcher" => "pathAll",
          "state" => "success"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "starting",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "running",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "stopping",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "stopped",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "failed",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "modifying",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "testing",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "deleting",
          "matcher" => "pathAny",
          "state" => "failure"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



805
806
807
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 805

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeReplicationTasksResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    Filters applied to replication tasks.

    Valid filter names: replication-task-arn | replication-task-id | migration-type | endpoint-arn | replication-instance-arn

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: Minimum 20, maximum 100.

  • :marker (String)

    An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.

  • :without_settings (Boolean)

    An option to set to avoid returning information about settings. Use this to reduce overhead when setting information is too large. To use this option, choose ‘true`; otherwise, choose `false` (the default).

Returns:



800
801
802
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 800

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end