Class: Aws::DatabaseMigrationService::Waiters::ReplicationTaskRunning

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb

Overview

Wait until DMS replication task is running.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ReplicationTaskRunning

Returns a new instance of ReplicationTaskRunning.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 818

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 60,
    delay: 15,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_replication_tasks,
      acceptors: [
        {
          "argument" => "replication_tasks[].status",
          "expected" => "running",
          "matcher" => "pathAll",
          "state" => "success"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "ready",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "creating",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "stopping",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "stopped",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "failed",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "modifying",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "testing",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "deleting",
          "matcher" => "pathAny",
          "state" => "failure"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



892
893
894
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 892

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeReplicationTasksResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    Filters applied to replication tasks.

    Valid filter names: replication-task-arn | replication-task-id | migration-type | endpoint-arn | replication-instance-arn

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: Minimum 20, maximum 100.

  • :marker (String)

    An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.

  • :without_settings (Boolean)

    An option to set to avoid returning information about settings. Use this to reduce overhead when setting information is too large. To use this option, choose ‘true`; otherwise, choose `false` (the default).

Returns:



887
888
889
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 887

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end