Class: Aws::DatabaseMigrationService::Types::CollectorHealthCheck

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Describes the last Fleet Advisor collector health check.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#collector_statusString

The status of the Fleet Advisor collector.



318
319
320
321
322
323
324
325
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 318

class CollectorHealthCheck < Struct.new(
  :collector_status,
  :local_collector_s3_access,
  :web_collector_s3_access,
  :web_collector_granted_role_based_access)
  SENSITIVE = []
  include Aws::Structure
end

#local_collector_s3_accessBoolean

Whether the local collector can access its Amazon S3 bucket.



318
319
320
321
322
323
324
325
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 318

class CollectorHealthCheck < Struct.new(
  :collector_status,
  :local_collector_s3_access,
  :web_collector_s3_access,
  :web_collector_granted_role_based_access)
  SENSITIVE = []
  include Aws::Structure
end

#web_collector_granted_role_based_accessBoolean

Whether the role that you provided when creating the Fleet Advisor collector has sufficient permissions to access the Fleet Advisor web collector.



318
319
320
321
322
323
324
325
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 318

class CollectorHealthCheck < Struct.new(
  :collector_status,
  :local_collector_s3_access,
  :web_collector_s3_access,
  :web_collector_granted_role_based_access)
  SENSITIVE = []
  include Aws::Structure
end

#web_collector_s3_accessBoolean

Whether the web collector can access its Amazon S3 bucket.



318
319
320
321
322
323
324
325
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 318

class CollectorHealthCheck < Struct.new(
  :collector_status,
  :local_collector_s3_access,
  :web_collector_s3_access,
  :web_collector_granted_role_based_access)
  SENSITIVE = []
  include Aws::Structure
end