Class: Aws::DatabaseMigrationService::Types::DataProvider
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DataProvider
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides information that defines a data provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_provider_arn ⇒ String
The Amazon Resource Name (ARN) string that uniquely identifies the data provider.
-
#data_provider_creation_time ⇒ Time
The time the data provider was created.
-
#data_provider_name ⇒ String
The name of the data provider.
-
#description ⇒ String
A description of the data provider.
-
#engine ⇒ String
The type of database engine for the data provider.
-
#settings ⇒ Types::DataProviderSettings
The settings in JSON format for a data provider.
-
#virtual ⇒ Boolean
Indicates whether the data provider is virtual.
Instance Attribute Details
#data_provider_arn ⇒ String
The Amazon Resource Name (ARN) string that uniquely identifies the data provider.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205 class DataProvider < Struct.new( :data_provider_name, :data_provider_arn, :data_provider_creation_time, :description, :engine, :virtual, :settings) SENSITIVE = [] include Aws::Structure end |
#data_provider_creation_time ⇒ Time
The time the data provider was created.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205 class DataProvider < Struct.new( :data_provider_name, :data_provider_arn, :data_provider_creation_time, :description, :engine, :virtual, :settings) SENSITIVE = [] include Aws::Structure end |
#data_provider_name ⇒ String
The name of the data provider.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205 class DataProvider < Struct.new( :data_provider_name, :data_provider_arn, :data_provider_creation_time, :description, :engine, :virtual, :settings) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the data provider. Descriptions can have up to 31 characters. A description can contain only ASCII letters, digits, and hyphens ('-'). Also, it can't end with a hyphen or contain two consecutive hyphens, and can only begin with a letter.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205 class DataProvider < Struct.new( :data_provider_name, :data_provider_arn, :data_provider_creation_time, :description, :engine, :virtual, :settings) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The type of database engine for the data provider.
Valid values: aurora, aurora-postgresql, db2, db2-zos,
docdb, mariadb, mongodb, mysql, oracle, postgres,
redshift, sqlserver, and sybase. A value of aurora
represents Amazon Aurora MySQL-Compatible Edition.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205 class DataProvider < Struct.new( :data_provider_name, :data_provider_arn, :data_provider_creation_time, :description, :engine, :virtual, :settings) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Types::DataProviderSettings
The settings in JSON format for a data provider.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205 class DataProvider < Struct.new( :data_provider_name, :data_provider_arn, :data_provider_creation_time, :description, :engine, :virtual, :settings) SENSITIVE = [] include Aws::Structure end |
#virtual ⇒ Boolean
Indicates whether the data provider is virtual.
2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 2205 class DataProvider < Struct.new( :data_provider_name, :data_provider_arn, :data_provider_creation_time, :description, :engine, :virtual, :settings) SENSITIVE = [] include Aws::Structure end |