Class: Aws::DatabaseMigrationService::Types::DescribeDataMigrationsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeDataMigrationsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Filters applied to the data migrations.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#without_settings ⇒ Boolean
An option to set to avoid returning information about settings.
-
#without_statistics ⇒ Boolean
An option to set to avoid returning information about statistics.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Filters applied to the data migrations.
3030 3031 3032 3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3030 class DescribeDataMigrationsMessage < Struct.new( :filters, :max_records, :marker, :without_settings, :without_statistics) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
3030 3031 3032 3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3030 class DescribeDataMigrationsMessage < Struct.new( :filters, :max_records, :marker, :without_settings, :without_statistics) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
3030 3031 3032 3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3030 class DescribeDataMigrationsMessage < Struct.new( :filters, :max_records, :marker, :without_settings, :without_statistics) SENSITIVE = [] include Aws::Structure end |
#without_settings ⇒ Boolean
An option to set to avoid returning information about settings. Use this to reduce overhead when setting information is too large. To use this option, choose true; otherwise, choose false (the default).
3030 3031 3032 3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3030 class DescribeDataMigrationsMessage < Struct.new( :filters, :max_records, :marker, :without_settings, :without_statistics) SENSITIVE = [] include Aws::Structure end |
#without_statistics ⇒ Boolean
An option to set to avoid returning information about statistics. Use this to reduce overhead when statistics information is too large. To use this option, choose true; otherwise, choose false (the default).
3030 3031 3032 3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3030 class DescribeDataMigrationsMessage < Struct.new( :filters, :max_records, :marker, :without_settings, :without_statistics) SENSITIVE = [] include Aws::Structure end |