Class: Aws::DatabaseMigrationService::Types::DescribeDataProvidersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeDataProvidersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
The filters to apply to the data providers.
-
#marker ⇒ String
Specifies the unique pagination token that makes it possible to display the next page of results.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
The filters to apply to the data providers.
The following filter names are supported:
data-provider-identifier– The data provider name or ARN.
^
3204 3205 3206 3207 3208 3209 3210 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3204 class DescribeDataProvidersMessage < Struct.new( :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Specifies the unique pagination token that makes it possible to
display the next page of results. If this parameter is specified,
the response includes only records beyond the marker, up to the
value specified by MaxRecords.
If Marker is returned by a previous response, there are more
results available. The value of Marker is a unique pagination
token for each page. To retrieve the next page, make the call again
using the returned token and keeping all other arguments unchanged.
3204 3205 3206 3207 3208 3209 3210 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3204 class DescribeDataProvidersMessage < Struct.new( :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, DMS includes a
pagination token in the response so that you can retrieve the
remaining results.
3204 3205 3206 3207 3208 3209 3210 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3204 class DescribeDataProvidersMessage < Struct.new( :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |