Class: Aws::DatabaseMigrationService::Types::DescribeEventsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeEventsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration ⇒ Integer
The duration of the events to be listed.
-
#end_time ⇒ Time
The end time for the events to be listed.
-
#event_categories ⇒ Array<String>
A list of event categories for the source type that you've chosen.
-
#filters ⇒ Array<Types::Filter>
Filters applied to events.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#source_identifier ⇒ String
The identifier of an event source.
-
#source_type ⇒ String
The type of DMS resource that generates events.
-
#start_time ⇒ Time
The start time for the events to be listed.
Instance Attribute Details
#duration ⇒ Integer
The duration of the events to be listed.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3570 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The end time for the events to be listed.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3570 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#event_categories ⇒ Array<String>
A list of event categories for the source type that you've chosen.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3570 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
Filters applied to events. The only valid filter is
replication-instance-id.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3570 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond
the marker, up to the value specified by MaxRecords.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3570 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so that the
remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3570 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source_identifier ⇒ String
The identifier of an event source.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3570 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The type of DMS resource that generates events.
Valid values: replication-instance | replication-task
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3570 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time for the events to be listed.
3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3570 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :event_categories, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |