Class: Aws::DatabaseMigrationService::Types::DescribeFleetAdvisorSchemaObjectSummaryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeFleetAdvisorSchemaObjectSummaryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
If you specify any of the following filters, the output includes information for only those schema objects that meet the filter criteria:.
-
#max_records ⇒ Integer
End of support notice: On May 20, 2026, Amazon Web Services will end support for Amazon Web Services DMS Fleet Advisor;.
-
#next_token ⇒ String
If
NextTokenis returned by a previous response, there are more results available.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
If you specify any of the following filters, the output includes information for only those schema objects that meet the filter criteria:
schema-id– The ID of the schema, for exampled4610ac5-e323-4ad9-bc50-eaf7249dfe9d.
^
Example: describe-fleet-advisor-schema-object-summary --filter Name="schema-id",Values="50"
3873 3874 3875 3876 3877 3878 3879 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3873 class DescribeFleetAdvisorSchemaObjectSummaryRequest < Struct.new( :filters, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
End of support notice: On May 20, 2026, Amazon Web Services will end support for Amazon Web Services DMS Fleet Advisor;. After May 20, 2026, you will no longer be able to access the Amazon Web Services DMS Fleet Advisor; console or Amazon Web Services DMS Fleet Advisor; resources. For more information, see Amazon Web Services DMS Fleet Advisor end of support.
Sets the maximum number of records returned in the response.
3873 3874 3875 3876 3877 3878 3879 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3873 class DescribeFleetAdvisorSchemaObjectSummaryRequest < Struct.new( :filters, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If NextToken is returned by a previous response, there are more
results available. The value of NextToken is a unique pagination
token for each page. Make the call again using the returned token to
retrieve the next page. Keep all other arguments unchanged.
3873 3874 3875 3876 3877 3878 3879 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 3873 class DescribeFleetAdvisorSchemaObjectSummaryRequest < Struct.new( :filters, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |