Class: Aws::DatabaseMigrationService::Types::DescribeMetadataModelCreationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeMetadataModelCreationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
Specifies the unique pagination token that makes it possible to display the next page of results.
-
#requests ⇒ Array<Types::SchemaConversionRequest>
A paginated list of metadata model creation requests.
Instance Attribute Details
#marker ⇒ String
Specifies the unique pagination token that makes it possible to
display the next page of results. If this parameter is specified,
the response includes only records beyond the marker, up to the
value specified by MaxRecords.
If Marker is returned by a previous response, there are more
results available. The value of Marker is a unique pagination
token for each page. To retrieve the next page, make the call again
using the returned token and keeping all other arguments unchanged.
4323 4324 4325 4326 4327 4328 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4323 class DescribeMetadataModelCreationsResponse < Struct.new( :marker, :requests) SENSITIVE = [] include Aws::Structure end |
#requests ⇒ Array<Types::SchemaConversionRequest>
A paginated list of metadata model creation requests.
ExportSqlDetails field for this operation.
4323 4324 4325 4326 4327 4328 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4323 class DescribeMetadataModelCreationsResponse < Struct.new( :marker, :requests) SENSITIVE = [] include Aws::Structure end |