Class: Aws::DatabaseMigrationService::Types::DescribeMetadataModelMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeMetadataModelMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
-
#origin ⇒ String
Specifies whether to retrieve metadata from the source or target tree.
-
#selection_rules ⇒ String
A JSON string that identifies the metadata model to retrieve.
Instance Attribute Details
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
4579 4580 4581 4582 4583 4584 4585 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4579 class DescribeMetadataModelMessage < Struct.new( :selection_rules, :migration_project_identifier, :origin) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
Specifies whether to retrieve metadata from the source or target tree. Valid values: SOURCE | TARGET
4579 4580 4581 4582 4583 4584 4585 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4579 class DescribeMetadataModelMessage < Struct.new( :selection_rules, :migration_project_identifier, :origin) SENSITIVE = [] include Aws::Structure end |
#selection_rules ⇒ String
A JSON string that identifies the metadata model to retrieve. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.
Usage:
-
Accepts source or target selection rules depending on the
Originparameter. Theserver-namein the object locator must match the corresponding data provider. -
Supports only
explicitrule actions. -
Exactly one rule is allowed.
4579 4580 4581 4582 4583 4584 4585 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4579 class DescribeMetadataModelMessage < Struct.new( :selection_rules, :migration_project_identifier, :origin) SENSITIVE = [] include Aws::Structure end |