Class: Aws::DatabaseMigrationService::Types::DescribeMigrationProjectsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::DescribeMigrationProjectsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
The filters to apply to the migration projects.
-
#marker ⇒ String
Specifies the unique pagination token that makes it possible to display the next page of results.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
The filters to apply to the migration projects.
The following filter names are supported:
-
migration-project-identifier– The migration project name or ARN. -
instance-profile-identifier– The instance profile name or ARN. -
data-provider-identifier– The source or target data provider name or ARN. -
source-data-provider-identifier– The source data provider name or ARN. -
target-data-provider-identifier– The target data provider name or ARN.
4658 4659 4660 4661 4662 4663 4664 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4658 class DescribeMigrationProjectsMessage < Struct.new( :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Specifies the unique pagination token that makes it possible to
display the next page of results. If this parameter is specified,
the response includes only records beyond the marker, up to the
value specified by MaxRecords.
If Marker is returned by a previous response, there are more
results available. The value of Marker is a unique pagination
token for each page. To retrieve the next page, make the call again
using the returned token and keeping all other arguments unchanged.
4658 4659 4660 4661 4662 4663 4664 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4658 class DescribeMigrationProjectsMessage < Struct.new( :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, DMS includes a
pagination token in the response so that you can retrieve the
remaining results.
4658 4659 4660 4661 4662 4663 4664 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 4658 class DescribeMigrationProjectsMessage < Struct.new( :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |