Class: Aws::DatabaseMigrationService::Types::GetTargetSelectionRulesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::GetTargetSelectionRulesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
-
#selection_rules ⇒ String
A JSON string that contains the source selection rules to convert into their target counterparts.
Instance Attribute Details
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
6726 6727 6728 6729 6730 6731 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6726 class GetTargetSelectionRulesMessage < Struct.new( :migration_project_identifier, :selection_rules) SENSITIVE = [] include Aws::Structure end |
#selection_rules ⇒ String
A JSON string that contains the source selection rules to convert into their target counterparts. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.
Usage:
-
Accepts only source selection rules, where
server-namein the object locator matches the source data provider. -
Supports only
explicitrule actions. -
Does not support
category-namein the object locator. -
Up to 10 rules are allowed.
6726 6727 6728 6729 6730 6731 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 6726 class GetTargetSelectionRulesMessage < Struct.new( :migration_project_identifier, :selection_rules) SENSITIVE = [] include Aws::Structure end |