Class: Aws::DatabaseMigrationService::Types::MetadataModelReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::MetadataModelReference
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
A reference to a metadata model, including its name and selection rules for location identification.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metadata_model_name ⇒ String
The name of the metadata model.
-
#selection_rules ⇒ String
A JSON string that identifies this metadata model in the metadata tree.
Instance Attribute Details
#metadata_model_name ⇒ String
The name of the metadata model.
7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7776 class MetadataModelReference < Struct.new( :metadata_model_name, :selection_rules) SENSITIVE = [] include Aws::Structure end |
#selection_rules ⇒ String
A JSON string that identifies this metadata model in the metadata tree. For the selection rule format, see Selection rules in DMS Schema Conversion.
Usage:
- You can pass this value as the
SelectionRulesparameter to any operation that accepts selection rules, such asDescribeMetadataModel,StartMetadataModelConversion, and others.
^
7776 7777 7778 7779 7780 7781 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 7776 class MetadataModelReference < Struct.new( :metadata_model_name, :selection_rules) SENSITIVE = [] include Aws::Structure end |