Class: Aws::DatabaseMigrationService::Types::ModifyConversionConfigurationMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::ModifyConversionConfigurationMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conversion_configuration ⇒ String
A JSON string that contains the schema conversion settings to update.
-
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
Instance Attribute Details
#conversion_configuration ⇒ String
A JSON string that contains the schema conversion settings to update. For the format and available settings, see Specifying schema conversion settings for migration projects.
Usage:
- Include only the sections and keys to change. The operation merges supplied values with the existing configuration.
^
8097 8098 8099 8100 8101 8102 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8097 class ModifyConversionConfigurationMessage < Struct.new( :migration_project_identifier, :conversion_configuration) SENSITIVE = [] include Aws::Structure end |
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
8097 8098 8099 8100 8101 8102 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 8097 class ModifyConversionConfigurationMessage < Struct.new( :migration_project_identifier, :conversion_configuration) SENSITIVE = [] include Aws::Structure end |