Class: Aws::DatabaseMigrationService::Types::RdsConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Provides information that describes the configuration of the recommended target engine on Amazon RDS.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_optionString

Describes the deployment option for the recommended Amazon RDS DB instance. The deployment options include Multi-AZ and Single-AZ deployments. Valid values include ‘“MULTI_AZ”` and `“SINGLE_AZ”`.



10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 10178

class RdsConfiguration < Struct.new(
  :engine_edition,
  :instance_type,
  :instance_vcpu,
  :instance_memory,
  :storage_type,
  :storage_size,
  :storage_iops,
  :deployment_option,
  :engine_version)
  SENSITIVE = []
  include Aws::Structure
end

#engine_editionString

Describes the recommended target Amazon RDS engine edition.



10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 10178

class RdsConfiguration < Struct.new(
  :engine_edition,
  :instance_type,
  :instance_vcpu,
  :instance_memory,
  :storage_type,
  :storage_size,
  :storage_iops,
  :deployment_option,
  :engine_version)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

Describes the recommended target Amazon RDS engine version.



10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 10178

class RdsConfiguration < Struct.new(
  :engine_edition,
  :instance_type,
  :instance_vcpu,
  :instance_memory,
  :storage_type,
  :storage_size,
  :storage_iops,
  :deployment_option,
  :engine_version)
  SENSITIVE = []
  include Aws::Structure
end

#instance_memoryFloat

Describes the memory on the recommended Amazon RDS DB instance that meets your requirements.



10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 10178

class RdsConfiguration < Struct.new(
  :engine_edition,
  :instance_type,
  :instance_vcpu,
  :instance_memory,
  :storage_type,
  :storage_size,
  :storage_iops,
  :deployment_option,
  :engine_version)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

Describes the recommended target Amazon RDS instance type.



10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 10178

class RdsConfiguration < Struct.new(
  :engine_edition,
  :instance_type,
  :instance_vcpu,
  :instance_memory,
  :storage_type,
  :storage_size,
  :storage_iops,
  :deployment_option,
  :engine_version)
  SENSITIVE = []
  include Aws::Structure
end

#instance_vcpuFloat

Describes the number of virtual CPUs (vCPU) on the recommended Amazon RDS DB instance that meets your requirements.



10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 10178

class RdsConfiguration < Struct.new(
  :engine_edition,
  :instance_type,
  :instance_vcpu,
  :instance_memory,
  :storage_type,
  :storage_size,
  :storage_iops,
  :deployment_option,
  :engine_version)
  SENSITIVE = []
  include Aws::Structure
end

#storage_iopsInteger

Describes the number of I/O operations completed each second (IOPS) on the recommended Amazon RDS DB instance that meets your requirements.



10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 10178

class RdsConfiguration < Struct.new(
  :engine_edition,
  :instance_type,
  :instance_vcpu,
  :instance_memory,
  :storage_type,
  :storage_size,
  :storage_iops,
  :deployment_option,
  :engine_version)
  SENSITIVE = []
  include Aws::Structure
end

#storage_sizeInteger

Describes the storage size of the recommended Amazon RDS DB instance that meets your requirements.



10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 10178

class RdsConfiguration < Struct.new(
  :engine_edition,
  :instance_type,
  :instance_vcpu,
  :instance_memory,
  :storage_type,
  :storage_size,
  :storage_iops,
  :deployment_option,
  :engine_version)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

Describes the storage type of the recommended Amazon RDS DB instance that meets your requirements.

Amazon RDS provides three storage types: General Purpose SSD (also known as gp2 and gp3), Provisioned IOPS SSD (also known as io1), and magnetic (also known as standard).



10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 10178

class RdsConfiguration < Struct.new(
  :engine_edition,
  :instance_type,
  :instance_vcpu,
  :instance_memory,
  :storage_type,
  :storage_size,
  :storage_iops,
  :deployment_option,
  :engine_version)
  SENSITIVE = []
  include Aws::Structure
end