Class: Aws::DatabaseMigrationService::Types::RedisSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Provides information that defines a Redis target endpoint.

Constant Summary collapse

SENSITIVE =
[:auth_password]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_passwordString

The password provided with the auth-role and auth-token options of the AuthType setting for a Redis target endpoint.

Returns:

  • (String)


11068
11069
11070
11071
11072
11073
11074
11075
11076
11077
11078
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11068

class RedisSettings < Struct.new(
  :server_name,
  :port,
  :ssl_security_protocol,
  :auth_type,
  :auth_user_name,
  :auth_password,
  :ssl_ca_certificate_arn)
  SENSITIVE = [:auth_password]
  include Aws::Structure
end

#auth_typeString

The type of authentication to perform when connecting to a Redis target. Options include none, auth-token, and auth-role. The auth-token option requires an AuthPassword value to be provided. The auth-role option requires AuthUserName and AuthPassword values to be provided.

Returns:

  • (String)


11068
11069
11070
11071
11072
11073
11074
11075
11076
11077
11078
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11068

class RedisSettings < Struct.new(
  :server_name,
  :port,
  :ssl_security_protocol,
  :auth_type,
  :auth_user_name,
  :auth_password,
  :ssl_ca_certificate_arn)
  SENSITIVE = [:auth_password]
  include Aws::Structure
end

#auth_user_nameString

The user name provided with the auth-role option of the AuthType setting for a Redis target endpoint.

Returns:

  • (String)


11068
11069
11070
11071
11072
11073
11074
11075
11076
11077
11078
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11068

class RedisSettings < Struct.new(
  :server_name,
  :port,
  :ssl_security_protocol,
  :auth_type,
  :auth_user_name,
  :auth_password,
  :ssl_ca_certificate_arn)
  SENSITIVE = [:auth_password]
  include Aws::Structure
end

#portInteger

Transmission Control Protocol (TCP) port for the endpoint.

Returns:

  • (Integer)


11068
11069
11070
11071
11072
11073
11074
11075
11076
11077
11078
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11068

class RedisSettings < Struct.new(
  :server_name,
  :port,
  :ssl_security_protocol,
  :auth_type,
  :auth_user_name,
  :auth_password,
  :ssl_ca_certificate_arn)
  SENSITIVE = [:auth_password]
  include Aws::Structure
end

#server_nameString

Fully qualified domain name of the endpoint.

Returns:

  • (String)


11068
11069
11070
11071
11072
11073
11074
11075
11076
11077
11078
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11068

class RedisSettings < Struct.new(
  :server_name,
  :port,
  :ssl_security_protocol,
  :auth_type,
  :auth_user_name,
  :auth_password,
  :ssl_ca_certificate_arn)
  SENSITIVE = [:auth_password]
  include Aws::Structure
end

#ssl_ca_certificate_arnString

The Amazon Resource Name (ARN) for the certificate authority (CA) that DMS uses to connect to your Redis target endpoint.

Returns:

  • (String)


11068
11069
11070
11071
11072
11073
11074
11075
11076
11077
11078
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11068

class RedisSettings < Struct.new(
  :server_name,
  :port,
  :ssl_security_protocol,
  :auth_type,
  :auth_user_name,
  :auth_password,
  :ssl_ca_certificate_arn)
  SENSITIVE = [:auth_password]
  include Aws::Structure
end

#ssl_security_protocolString

The connection to a Redis target endpoint using Transport Layer Security (TLS). Valid values include plaintext and ssl-encryption. The default is ssl-encryption. The ssl-encryption option makes an encrypted connection. Optionally, you can identify an Amazon Resource Name (ARN) for an SSL certificate authority (CA) using the SslCaCertificateArn setting. If an ARN isn't given for a CA, DMS uses the Amazon root CA.

The plaintext option doesn't provide Transport Layer Security (TLS) encryption for traffic between endpoint and database.

Returns:

  • (String)


11068
11069
11070
11071
11072
11073
11074
11075
11076
11077
11078
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 11068

class RedisSettings < Struct.new(
  :server_name,
  :port,
  :ssl_security_protocol,
  :auth_type,
  :auth_user_name,
  :auth_password,
  :ssl_ca_certificate_arn)
  SENSITIVE = [:auth_password]
  include Aws::Structure
end