Class: Aws::DatabaseMigrationService::Types::SchemaConversionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::SchemaConversionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Provides information about a schema conversion action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error ⇒ Types::ErrorDetails
Provides error information about a project.
-
#export_sql_details ⇒ Types::ExportSqlDetails
The Amazon S3 location of the ZIP archive that contains the exported data definition language (DDL) scripts.
-
#migration_project_arn ⇒ String
The migration project ARN.
-
#progress ⇒ Types::Progress
Provides information about the progress of the schema conversion operation.
-
#request_identifier ⇒ String
The identifier for the schema conversion action.
-
#status ⇒ String
The schema conversion operation status.
Instance Attribute Details
#error ⇒ Types::ErrorDetails
Provides error information about a project.
13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13935 class SchemaConversionRequest < Struct.new( :status, :request_identifier, :migration_project_arn, :error, :export_sql_details, :progress) SENSITIVE = [] include Aws::Structure end |
#export_sql_details ⇒ Types::ExportSqlDetails
The Amazon S3 location of the ZIP archive that contains the exported data definition language (DDL) scripts.
DescribeMetadataModelExportsAsScript operation.
13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13935 class SchemaConversionRequest < Struct.new( :status, :request_identifier, :migration_project_arn, :error, :export_sql_details, :progress) SENSITIVE = [] include Aws::Structure end |
#migration_project_arn ⇒ String
The migration project ARN.
13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13935 class SchemaConversionRequest < Struct.new( :status, :request_identifier, :migration_project_arn, :error, :export_sql_details, :progress) SENSITIVE = [] include Aws::Structure end |
#progress ⇒ Types::Progress
Provides information about the progress of the schema conversion operation.
13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13935 class SchemaConversionRequest < Struct.new( :status, :request_identifier, :migration_project_arn, :error, :export_sql_details, :progress) SENSITIVE = [] include Aws::Structure end |
#request_identifier ⇒ String
The identifier for the schema conversion action.
13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13935 class SchemaConversionRequest < Struct.new( :status, :request_identifier, :migration_project_arn, :error, :export_sql_details, :progress) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The schema conversion operation status. Possible values:
-
RECEIVED– The operation is received but not yet queued for processing. -
IN_PROGRESS– The operation is queued or actively running. -
SUCCESS– The operation completed successfully. -
FAILED– The operation did not complete. -
CANCELING– The operation is being canceled. The operation might still succeed or fail before cancellation takes effect. -
CANCELED– The operation was canceled before completion.
13935 13936 13937 13938 13939 13940 13941 13942 13943 13944 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13935 class SchemaConversionRequest < Struct.new( :status, :request_identifier, :migration_project_arn, :error, :export_sql_details, :progress) SENSITIVE = [] include Aws::Structure end |