Class: Aws::DatabaseMigrationService::Types::StartMetadataModelCreationMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::StartMetadataModelCreationMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metadata_model_name ⇒ String
The name for the metadata model to use in subsequent operations.
-
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
-
#properties ⇒ Types::MetadataModelProperties
The properties of the metadata model.
-
#selection_rules ⇒ String
A JSON string that identifies the source schema for the metadata model.
Instance Attribute Details
#metadata_model_name ⇒ String
The name for the metadata model to use in subsequent operations.
14270 14271 14272 14273 14274 14275 14276 14277 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14270 class StartMetadataModelCreationMessage < Struct.new( :migration_project_identifier, :selection_rules, :metadata_model_name, :properties) SENSITIVE = [] include Aws::Structure end |
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
14270 14271 14272 14273 14274 14275 14276 14277 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14270 class StartMetadataModelCreationMessage < Struct.new( :migration_project_identifier, :selection_rules, :metadata_model_name, :properties) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Types::MetadataModelProperties
The properties of the metadata model.
14270 14271 14272 14273 14274 14275 14276 14277 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14270 class StartMetadataModelCreationMessage < Struct.new( :migration_project_identifier, :selection_rules, :metadata_model_name, :properties) SENSITIVE = [] include Aws::Structure end |
#selection_rules ⇒ String
A JSON string that identifies the source schema for the metadata model. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.
Usage:
-
Accepts only source selection rules, where
server-namein the object locator matches the source data provider. -
Supports only
explicitrule actions. -
Exactly one rule is allowed.
14270 14271 14272 14273 14274 14275 14276 14277 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14270 class StartMetadataModelCreationMessage < Struct.new( :migration_project_identifier, :selection_rules, :metadata_model_name, :properties) SENSITIVE = [] include Aws::Structure end |