Class: Aws::DatabaseMigrationService::Types::StartMetadataModelExportAsScriptMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::StartMetadataModelExportAsScriptMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_name ⇒ String
The name for the exported file.
-
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
-
#origin ⇒ String
Specifies the metadata tree to export from.
-
#selection_rules ⇒ String
A JSON string that identifies the metadata models to export as a SQL script.
Instance Attribute Details
#file_name ⇒ String
The name for the exported file. When you omit this parameter, the service generates a name from the data provider engine name and an export timestamp.
14325 14326 14327 14328 14329 14330 14331 14332 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14325 class StartMetadataModelExportAsScriptMessage < Struct.new( :migration_project_identifier, :selection_rules, :origin, :file_name) SENSITIVE = [] include Aws::Structure end |
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
14325 14326 14327 14328 14329 14330 14331 14332 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14325 class StartMetadataModelExportAsScriptMessage < Struct.new( :migration_project_identifier, :selection_rules, :origin, :file_name) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
Specifies the metadata tree to export from.
14325 14326 14327 14328 14329 14330 14331 14332 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14325 class StartMetadataModelExportAsScriptMessage < Struct.new( :migration_project_identifier, :selection_rules, :origin, :file_name) SENSITIVE = [] include Aws::Structure end |
#selection_rules ⇒ String
A JSON string that identifies the metadata models to export as a SQL script. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.
Usage:
-
Accepts source or target selection rules depending on the
Originparameter. Theserver-namein the object locator must match the corresponding data provider. -
Supports
explicit,include, andexcluderule actions.
14325 14326 14327 14328 14329 14330 14331 14332 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14325 class StartMetadataModelExportAsScriptMessage < Struct.new( :migration_project_identifier, :selection_rules, :origin, :file_name) SENSITIVE = [] include Aws::Structure end |