Class: Aws::DatabaseMigrationService::Types::StartMetadataModelExportToTargetMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::StartMetadataModelExportToTargetMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
-
#overwrite_extension_pack ⇒ Boolean
Specifies whether to overwrite the extension pack if one already exists on the target database.
-
#selection_rules ⇒ String
A JSON string that identifies the metadata models to export to the target database.
Instance Attribute Details
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
14374 14375 14376 14377 14378 14379 14380 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14374 class StartMetadataModelExportToTargetMessage < Struct.new( :migration_project_identifier, :selection_rules, :overwrite_extension_pack) SENSITIVE = [] include Aws::Structure end |
#overwrite_extension_pack ⇒ Boolean
Specifies whether to overwrite the extension pack if one already
exists on the target database. The default value is true.
14374 14375 14376 14377 14378 14379 14380 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14374 class StartMetadataModelExportToTargetMessage < Struct.new( :migration_project_identifier, :selection_rules, :overwrite_extension_pack) SENSITIVE = [] include Aws::Structure end |
#selection_rules ⇒ String
A JSON string that identifies the metadata models to export to the target database. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.
Usage:
-
Accepts only target selection rules, where
server-namein the object locator matches the target data provider. -
Supports
explicit,include, andexcluderule actions.
14374 14375 14376 14377 14378 14379 14380 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14374 class StartMetadataModelExportToTargetMessage < Struct.new( :migration_project_identifier, :selection_rules, :overwrite_extension_pack) SENSITIVE = [] include Aws::Structure end |