Class: Aws::DatabaseMigrationService::Types::StartMetadataModelImportMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DatabaseMigrationService::Types::StartMetadataModelImportMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-databasemigrationservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
-
#origin ⇒ String
Specifies the metadata tree to import into.
-
#refresh ⇒ Boolean
Specifies whether to refresh the selected metadata models from the data provider.
-
#selection_rules ⇒ String
A JSON string that identifies the metadata models to import from the data provider.
Instance Attribute Details
#migration_project_identifier ⇒ String
The migration project name or Amazon Resource Name (ARN).
14437 14438 14439 14440 14441 14442 14443 14444 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14437 class StartMetadataModelImportMessage < Struct.new( :migration_project_identifier, :selection_rules, :origin, :refresh) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
Specifies the metadata tree to import into.
14437 14438 14439 14440 14441 14442 14443 14444 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14437 class StartMetadataModelImportMessage < Struct.new( :migration_project_identifier, :selection_rules, :origin, :refresh) SENSITIVE = [] include Aws::Structure end |
#refresh ⇒ Boolean
Specifies whether to refresh the selected metadata models from the data provider.
When true, the import reloads the selected metadata models with
current definitions and removes their existing subtree.
When false (default), the import loads the full subtree that has
not yet been loaded into the metadata tree.
14437 14438 14439 14440 14441 14442 14443 14444 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14437 class StartMetadataModelImportMessage < Struct.new( :migration_project_identifier, :selection_rules, :origin, :refresh) SENSITIVE = [] include Aws::Structure end |
#selection_rules ⇒ String
A JSON string that identifies the metadata models to import from the data provider. For the selection rule format and examples, see Selection rules in DMS Schema Conversion.
Usage:
-
Accepts source or target selection rules depending on the
Originparameter. Theserver-namein the object locator must match the corresponding data provider. -
Supports
explicit,include, andexcluderule actions.
14437 14438 14439 14440 14441 14442 14443 14444 |
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 14437 class StartMetadataModelImportMessage < Struct.new( :migration_project_identifier, :selection_rules, :origin, :refresh) SENSITIVE = [] include Aws::Structure end |