Class: Aws::DatabaseMigrationService::Types::StartReplicationTaskMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-databasemigrationservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cdc_start_positionString

Indicates when you want a change data capture (CDC) operation to start. Use either CdcStartPosition or CdcStartTime to specify when you want a CDC operation to start. Specifying both values results in an error.

The value can be in date, checkpoint, or LSN/SCN format.

Date Example: –cdc-start-position “2018-03-08T12:12:12”

Checkpoint Example: –cdc-start-position “checkpoint:V1#27#mysql-bin-changelog.157832:1975:-1:2002:677883278264080:mysql-bin-changelog.157832:1876#0#0#*#0#93”

LSN Example: –cdc-start-position “mysql-bin-changelog.000024:373”

<note markdown=“1”> When you use this task setting with a source PostgreSQL database, a logical replication slot should already be created and associated with the source endpoint. You can verify this by setting the slotName extra connection attribute to the name of this logical replication slot. For more information, see [Extra Connection Attributes When Using PostgreSQL as a Source for DMS].

</note>

[1]: docs.aws.amazon.com/dms/latest/userguide/CHAP_Source.PostgreSQL.html#CHAP_Source.PostgreSQL.ConnectionAttrib

Returns:

  • (String)


13795
13796
13797
13798
13799
13800
13801
13802
13803
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13795

class StartReplicationTaskMessage < Struct.new(
  :replication_task_arn,
  :start_replication_task_type,
  :cdc_start_time,
  :cdc_start_position,
  :cdc_stop_position)
  SENSITIVE = []
  include Aws::Structure
end

#cdc_start_timeTime

Indicates the start time for a change data capture (CDC) operation. Use either CdcStartTime or CdcStartPosition to specify when you want a CDC operation to start. Specifying both values results in an error.

Timestamp Example: –cdc-start-time “2018-03-08T12:12:12”

Returns:

  • (Time)


13795
13796
13797
13798
13799
13800
13801
13802
13803
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13795

class StartReplicationTaskMessage < Struct.new(
  :replication_task_arn,
  :start_replication_task_type,
  :cdc_start_time,
  :cdc_start_position,
  :cdc_stop_position)
  SENSITIVE = []
  include Aws::Structure
end

#cdc_stop_positionString

Indicates when you want a change data capture (CDC) operation to stop. The value can be either server time or commit time.

Server time example: –cdc-stop-position “server_time:2018-02-09T12:12:12”

Commit time example: –cdc-stop-position “commit_time:2018-02-09T12:12:12“

Returns:

  • (String)


13795
13796
13797
13798
13799
13800
13801
13802
13803
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13795

class StartReplicationTaskMessage < Struct.new(
  :replication_task_arn,
  :start_replication_task_type,
  :cdc_start_time,
  :cdc_start_position,
  :cdc_stop_position)
  SENSITIVE = []
  include Aws::Structure
end

#replication_task_arnString

The Amazon Resource Name (ARN) of the replication task to be started.

Returns:

  • (String)


13795
13796
13797
13798
13799
13800
13801
13802
13803
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13795

class StartReplicationTaskMessage < Struct.new(
  :replication_task_arn,
  :start_replication_task_type,
  :cdc_start_time,
  :cdc_start_position,
  :cdc_stop_position)
  SENSITIVE = []
  include Aws::Structure
end

#start_replication_task_typeString

The type of replication task to start.

When the migration type is full-load or full-load-and-cdc, the only valid value for the first run of the task is start-replication. This option will start the migration.

You can also use ReloadTables to reload specific tables that failed during migration instead of restarting the task.

The resume-processing option isn’t applicable for a full-load task, because you can’t resume partially loaded tables during the full load phase.

For a full-load-and-cdc task, DMS migrates table data, and then applies data changes that occur on the source. To load all the tables again, and start capturing source changes, use reload-target. Otherwise use resume-processing, to replicate the changes from the last stop position.

Returns:

  • (String)


13795
13796
13797
13798
13799
13800
13801
13802
13803
# File 'lib/aws-sdk-databasemigrationservice/types.rb', line 13795

class StartReplicationTaskMessage < Struct.new(
  :replication_task_arn,
  :start_replication_task_type,
  :cdc_start_time,
  :cdc_start_position,
  :cdc_stop_position)
  SENSITIVE = []
  include Aws::Structure
end