Class: Aws::DatabaseMigrationService::Waiters::EndpointDeleted
- Inherits:
-
Object
- Object
- Aws::DatabaseMigrationService::Waiters::EndpointDeleted
- Defined in:
- lib/aws-sdk-databasemigrationservice/waiters.rb,
sig/waiters.rbs
Overview
Wait until testing endpoint is deleted.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ EndpointDeleted
constructor
A new instance of EndpointDeleted.
-
#wait(params = {}) ⇒ Types::DescribeEndpointsResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ EndpointDeleted
Returns a new instance of EndpointDeleted.
101 102 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 101
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
138 139 140 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 138 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeEndpointsResponse
Returns a response object which responds to the following methods:
- #marker => String
- #endpoints => Array<Types::Endpoint>
133 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 133
def wait: (
|