Class: Aws::DatabaseMigrationService::Waiters::EndpointDeleted
- Inherits:
-
Object
- Object
- Aws::DatabaseMigrationService::Waiters::EndpointDeleted
- Defined in:
- lib/aws-sdk-databasemigrationservice/waiters.rb
Overview
Wait until testing endpoint is deleted.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ EndpointDeleted
constructor
A new instance of EndpointDeleted.
-
#wait(params = {}) ⇒ Types::DescribeEndpointsResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ EndpointDeleted
Returns a new instance of EndpointDeleted.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 101 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 60, delay: 5, poller: Aws::Waiters::Poller.new( operation_name: :describe_endpoints, acceptors: [ { "expected" => "ResourceNotFoundFault", "matcher" => "error", "state" => "success" }, { "argument" => "endpoints[].status", "expected" => "active", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "endpoints[].status", "expected" => "creating", "matcher" => "pathAny", "state" => "failure" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
138 139 140 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 138 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeEndpointsResponse
Returns a response object which responds to the following methods:
-
#marker => String
-
#endpoints => Array<Types::Endpoint>
133 134 135 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 133 def wait(params = {}) @waiter.wait(client: @client, params: params) end |