Class: Aws::DatabaseMigrationService::Waiters::ExtensionPackAssociated

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb

Overview

Wait until DMS extension pack is associated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ExtensionPackAssociated

Returns a new instance of ExtensionPackAssociated.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 151

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 60,
    delay: 10,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_extension_pack_associations,
      acceptors: [
        {
          "argument" => "requests[].status",
          "expected" => "SUCCESS",
          "matcher" => "pathAll",
          "state" => "success"
        },
        {
          "argument" => "requests[].status",
          "expected" => "FAILED",
          "matcher" => "pathAny",
          "state" => "failure"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



183
184
185
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 183

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeExtensionPackAssociationsResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :migration_project_identifier (required, String)

    The name or Amazon Resource Name (ARN) for the migration project.

  • :filters (Array<Types::Filter>)

    Filters applied to the extension pack associations described in the form of key-value pairs.

  • :marker (String)

    Specifies the unique pagination token that makes it possible to display the next page of results. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.

    If ‘Marker` is returned by a previous response, there are more results available. The value of `Marker` is a unique pagination token for each page. To retrieve the next page, make the call again using the returned token and keeping all other arguments unchanged.

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, DMS includes a pagination token in the response so that you can retrieve the remaining results.

Returns:



178
179
180
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 178

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end