Class: Aws::DatabaseMigrationService::Waiters::MetadataModelConversionCancelled

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb

Overview

Wait until DMS metadata model conversion is cancelled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ MetadataModelConversionCancelled

Returns a new instance of MetadataModelConversionCancelled.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 180
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 241

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 180,
    delay: 10,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_metadata_model_conversions,
      acceptors: [
        {
          "argument" => "requests[].status",
          "expected" => "CANCELED",
          "matcher" => "pathAll",
          "state" => "success"
        },
        {
          "argument" => "requests[].status",
          "expected" => "FAILED",
          "matcher" => "pathAny",
          "state" => "failure"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



273
274
275
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 273

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeMetadataModelConversionsResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :migration_project_identifier (required, String)

    The migration project name or Amazon Resource Name (ARN).

  • :filters (Array<Types::Filter>)

    Filters applied to the metadata model conversions described in the form of key-value pairs.

  • :marker (String)

    Specifies the unique pagination token that makes it possible to display the next page of results. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.

    If ‘Marker` is returned by a previous response, there are more results available. The value of `Marker` is a unique pagination token for each page. To retrieve the next page, make the call again using the returned token and keeping all other arguments unchanged.

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, DMS includes a pagination token in the response so that you can retrieve the remaining results.

Returns:



268
269
270
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 268

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end