Class: Aws::DatabaseMigrationService::Waiters::MetadataModelCreationCancelled

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb

Overview

Wait until DMS metadata model creation is cancelled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ MetadataModelCreationCancelled

Returns a new instance of MetadataModelCreationCancelled.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 180
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 376

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 180,
    delay: 10,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_metadata_model_creations,
      acceptors: [
        {
          "argument" => "requests[].status",
          "expected" => "CANCELED",
          "matcher" => "pathAll",
          "state" => "success"
        },
        {
          "argument" => "requests[].status",
          "expected" => "FAILED",
          "matcher" => "pathAny",
          "state" => "failure"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



408
409
410
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 408

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeMetadataModelCreationsResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    Filters applied to the metadata model creation requests described in the form of key-value pairs. The supported filters are request-id and status.

  • :marker (String)

    Specifies the unique pagination token that makes it possible to display the next page of metadata model creation requests. If Marker is returned by a previous response, there are more metadata model creation requests available.

  • :max_records (Integer)

    The maximum number of metadata model creation requests to include in the response. If more requests exist than the specified MaxRecords value, a pagination token is provided in the response so that you can retrieve the remaining results.

  • :migration_project_identifier (required, String)

    The migration project name or Amazon Resource Name (ARN).

Returns:



403
404
405
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 403

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end