Class: Aws::DatabaseMigrationService::Waiters::MetadataModelExportedToTarget

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb

Overview

Wait until DMS metadata model is exported to target.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ MetadataModelExportedToTarget

Returns a new instance of MetadataModelExportedToTarget.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 90
  • :delay (Integer) — default: 20
  • :before_attempt (Proc)
  • :before_wait (Proc)


466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 466

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 90,
    delay: 20,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_metadata_model_exports_to_target,
      acceptors: [
        {
          "argument" => "requests[].status",
          "expected" => "SUCCESS",
          "matcher" => "pathAll",
          "state" => "success"
        },
        {
          "argument" => "requests[].status",
          "expected" => "FAILED",
          "matcher" => "pathAny",
          "state" => "failure"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



498
499
500
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 498

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeMetadataModelExportsToTargetResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :migration_project_identifier (required, String)

    The migration project name or Amazon Resource Name (ARN).

  • :filters (Array<Types::Filter>)

    Filters applied to the metadata model exports described in the form of key-value pairs.

  • :marker (String)

    Specifies the unique pagination token that makes it possible to display the next page of results. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.

    If ‘Marker` is returned by a previous response, there are more results available. The value of `Marker` is a unique pagination token for each page. To retrieve the next page, make the call again using the returned token and keeping all other arguments unchanged.

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, DMS includes a pagination token in the response so that you can retrieve the remaining results.

Returns:



493
494
495
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 493

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end