Class: Aws::DatabaseMigrationService::Waiters::ReplicationTaskDeleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-databasemigrationservice/waiters.rb

Overview

Wait until DMS replication task is deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ReplicationTaskDeleted

Returns a new instance of ReplicationTaskDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 663

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 60,
    delay: 15,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_replication_tasks,
      acceptors: [
        {
          "argument" => "replication_tasks[].status",
          "expected" => "ready",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "creating",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "stopped",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "running",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "argument" => "replication_tasks[].status",
          "expected" => "failed",
          "matcher" => "pathAny",
          "state" => "failure"
        },
        {
          "expected" => "ResourceNotFoundFault",
          "matcher" => "error",
          "state" => "success"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



718
719
720
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 718

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeReplicationTasksResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :filters (Array<Types::Filter>)

    Filters applied to replication tasks.

    Valid filter names: replication-task-arn | replication-task-id | migration-type | endpoint-arn | replication-instance-arn

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: Minimum 20, maximum 100.

  • :marker (String)

    An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.

  • :without_settings (Boolean)

    An option to set to avoid returning information about settings. Use this to reduce overhead when setting information is too large. To use this option, choose ‘true`; otherwise, choose `false` (the default).

Returns:



713
714
715
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 713

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end