Class: Aws::DatabaseMigrationService::Waiters::ReplicationTaskDeleted
- Inherits:
-
Object
- Object
- Aws::DatabaseMigrationService::Waiters::ReplicationTaskDeleted
- Defined in:
- lib/aws-sdk-databasemigrationservice/waiters.rb
Overview
Wait until DMS replication task is deleted.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ReplicationTaskDeleted
constructor
A new instance of ReplicationTaskDeleted.
-
#wait(params = {}) ⇒ Types::DescribeReplicationTasksResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ReplicationTaskDeleted
Returns a new instance of ReplicationTaskDeleted.
663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 663 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 60, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_replication_tasks, acceptors: [ { "argument" => "replication_tasks[].status", "expected" => "ready", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "replication_tasks[].status", "expected" => "creating", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "replication_tasks[].status", "expected" => "stopped", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "replication_tasks[].status", "expected" => "running", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "replication_tasks[].status", "expected" => "failed", "matcher" => "pathAny", "state" => "failure" }, { "expected" => "ResourceNotFoundFault", "matcher" => "error", "state" => "success" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
718 719 720 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 718 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeReplicationTasksResponse
Returns a response object which responds to the following methods:
-
#marker => String
-
#replication_tasks => Array<Types::ReplicationTask>
713 714 715 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 713 def wait(params = {}) @waiter.wait(client: @client, params: params) end |