Class: Aws::DatabaseMigrationService::Waiters::ReplicationTaskRunning
- Inherits:
-
Object
- Object
- Aws::DatabaseMigrationService::Waiters::ReplicationTaskRunning
- Defined in:
- lib/aws-sdk-databasemigrationservice/waiters.rb
Overview
Wait until DMS replication task is running.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ReplicationTaskRunning
constructor
A new instance of ReplicationTaskRunning.
-
#wait(params = {}) ⇒ Types::DescribeReplicationTasksResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ReplicationTaskRunning
Returns a new instance of ReplicationTaskRunning.
818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 818 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 60, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_replication_tasks, acceptors: [ { "argument" => "replication_tasks[].status", "expected" => "running", "matcher" => "pathAll", "state" => "success" }, { "argument" => "replication_tasks[].status", "expected" => "ready", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "replication_tasks[].status", "expected" => "creating", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "replication_tasks[].status", "expected" => "stopping", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "replication_tasks[].status", "expected" => "stopped", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "replication_tasks[].status", "expected" => "failed", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "replication_tasks[].status", "expected" => "modifying", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "replication_tasks[].status", "expected" => "testing", "matcher" => "pathAny", "state" => "failure" }, { "argument" => "replication_tasks[].status", "expected" => "deleting", "matcher" => "pathAny", "state" => "failure" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
892 893 894 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 892 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeReplicationTasksResponse
Returns a response object which responds to the following methods:
-
#marker => String
-
#replication_tasks => Array<Types::ReplicationTask>
887 888 889 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 887 def wait(params = {}) @waiter.wait(client: @client, params: params) end |