Class: Aws::DatabaseMigrationService::Waiters::TestConnectionSucceeds
- Inherits:
-
Object
- Object
- Aws::DatabaseMigrationService::Waiters::TestConnectionSucceeds
- Defined in:
- lib/aws-sdk-databasemigrationservice/waiters.rb
Overview
Wait until testing connection succeeds.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ TestConnectionSucceeds
constructor
A new instance of TestConnectionSucceeds.
-
#wait(params = {}) ⇒ Types::DescribeConnectionsResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ TestConnectionSucceeds
Returns a new instance of TestConnectionSucceeds.
986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 986 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 60, delay: 5, poller: Aws::Waiters::Poller.new( operation_name: :describe_connections, acceptors: [ { "argument" => "connections[].status", "expected" => "successful", "matcher" => "pathAll", "state" => "success" }, { "argument" => "connections[].status", "expected" => "failed", "matcher" => "pathAny", "state" => "failure" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1018 1019 1020 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 1018 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeConnectionsResponse
Returns a response object which responds to the following methods:
-
#marker => String
-
#connections => Array<Types::Connection>
1013 1014 1015 |
# File 'lib/aws-sdk-databasemigrationservice/waiters.rb', line 1013 def wait(params = {}) @waiter.wait(client: @client, params: params) end |